/******************************************************************************* 
	Project: The Economics of Women Entrepreneurship
	Paper: Economic Inclusion through Entrepreneurship: Evidence on Building 
		   Skills for Women
	Title: Impact Evaluation Analysis and Tables Creation
	Authors: Megan Lang and Julia Seither
	RA: Maria Sofia Casabianca

	Description: This Do-file presents the analysis in which the paper is based.
				 It creates all the appendix tables used in the paper.
	
	STATA version: 18

	Date: Sep 25 - 2024 (Last Update)										 
*******************************************************************************/

********************************************************************************
******************************* DATA PREPARATION *******************************
********************************************************************************
clear all
set more off
set varabbrev off

use "$path/../Data/IE_Submission.dta", clear

sort id sur_round
xtset id sur_round

********************************************************************************
*********************** PROGRAM DEFINITION FOR Q-VALUES ************************
********************************************************************************
/*NOTE:
This is taken directly from Michael Anderson's Stata code, which "generates BKY 
(2006) sharpened two-stage q-values as described in Anderson (2008), "Multiple 
Inference and Gender Differences in the Effects of Early Intervention: A Reeva-
luation of the Abecedarian, Perry Preschool, and Early Training Projects", Jour-
nal of the American Statistical Association, 103(484), 1481-1495.

The original code is found in: https://are.berkeley.edu/~mlanderson/ARE_Website/Research.html
*/
program define gen_qvals, rclass
	version 18.0
	
// Collect the total number of p-values tested
	quietly sum pval
	local totalpvals = r(N)
// Sort the p-values in ascending order and generate a variable that codes each p-value's rank
	quietly gen int original_sorting_order = _n
	quietly sort pval
	quietly gen int rank = _n if pval != .
	
// Set the initial counter to 1 
	local qval = 1
	
// Generate the variable that will contain the BKY (2006) sharpened q-values
	gen bky06_qval = 1 if pval != .

// Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.
while `qval' > 0 {
	// First Stage
	// Generate the adjusted first stage q level we are testing: q' = q/1+q
	local qval_adj = `qval' / ( 1 + `qval' )
	// Generate value q'//r/M
	gen fdr_temp1 = `qval_adj' * rank / `totalpvals'
	// Generate binary variable checking condition p(r) <= q'*r/M
	gen reject_temp1 = ( fdr_temp1 >= pval ) if pval != .
	// Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank1 = reject_temp1 * rank
	// Record the rank of the largest p-value that meets above condition
	egen total_rejected1 = max( reject_rank1 )

	// Second Stage
	// Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
	local qval_2st = `qval_adj' * ( `totalpvals' / ( `totalpvals' - total_rejected1[1] ) )
	// Generate value q_2st*r/M
	gen fdr_temp2 = `qval_2st' * rank / `totalpvals'
	// Generate binary variable checking condition p(r) <= q_2st*r/M
	gen reject_temp2 = ( fdr_temp2 >= pval ) if pval != .
	// Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank2 = reject_temp2 * rank
	// Record the rank of the largest p-value that meets above condition
	egen total_rejected2 = max( reject_rank2 )

	// A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
	replace bky06_qval = `qval' if rank <= total_rejected2 & rank != .
	// Reduce q by 0.001 and repeat loop
	drop fdr_temp* reject_temp* reject_rank* total_rejected*
	local qval = `qval' - .001
}
	
	quietly sort original_sorting_order
	
	list Outcome coef pval bky06_qval original_sorting_order 
	
	mkmat original_sorting_order coef pval bky06_qval, matrix(Adj_qval)
	
end

********************************************************************************
************************ CONTROL GLOBALS AND COVARIATES ************************
********************************************************************************
global controls = "i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age"

global controlsBalance = "b_age	b_mar	b_div	b_sing	b_prim	b_sec	b_p_prim	b_p_sec	b_m_prim	b_m_sec	b_employed	b_hh_size	b_minors	b_dexp_hh_w	b_savings_w	b_remittances_w	b_b0	b_sales_last3_w	b_srp_w	b_ob_srp_w	b_network	b_loc_int	b_loc_po	b_loc_chance"

preserve
/*******************************************************************************
								  BASELINE BALANCE

			Table A1. Balance Table
			File name: balance.tex
*******************************************************************************/
gen treatment=.
replace treatment=0 if (tmt=="C")
replace treatment=1 if tmt=="B"

lab var b_age "Age"
lab var b_mar "Married"
lab var b_div "Divorced"
lab var b_sing "Single"
lab var b_wid "Widowed"
lab var b_prim "Primary Ed."
lab var b_sec "Secondary Ed."
lab var b_p_prim "Father Primary Ed."
lab var b_p_sec "Father Secondary Ed."
lab var b_m_prim "Mother Primary Ed."
lab var b_m_sec "Mother Secondary Ed."
lab var b_employed "Employed"
lab var b_hh_size "HH Size"
lab var b_minors "Minors in HH"
lab var b_dexp_hh_w "Daily Expenditure HH"
lab var b_savings_w "Savings"
lab var b_remittances_w "Remittances"
lab var b_b0 "Own a Business"
lab var b_sales_last3_w "Sales - MB"
lab var b_srp_w "Profits - MB"
lab var b_ob_srp_w "Profits - OB"
lab var b_network "Network Size"
lab var b_loc_int "Locus - Internal"
lab var b_loc_po "Locus - PO"
lab var b_loc_chance "Locus - Chance"

******************************* Table File Code ********************************
cd "$path/../Output/Tables"
	
iebaltab b_age	b_mar	b_div	b_sing	b_wid	b_prim	b_sec	b_p_prim	b_p_sec	b_m_prim	b_m_sec	b_employed	b_hh_size	b_minors	b_dexp_hh_w	b_savings_w	b_remittances_w	b_b0	b_sales_last3_w	b_srp_w	b_ob_srp_w	b_network	b_loc_int	b_loc_po	b_loc_chance if sur_round==1, replace ///
	grpvar(treatment) savet(balance) ///
	stats(desc(sd) feq(p)) rowvarlabels starsno ///
	addnote("Mean baseline covariates by treatment group. Standard deviations are in parentheses. The last column reports p-values associated with T-tests of joint equality between the groups.") texnotewidth(0.9) grplabels(0 Control @ 1 Treatment) tblnon
	
cd "$path/"
	
/*******************************************************************************
							ATTRITION BY SURVEY ROUND
	   
	Table A2. Attrition
	File name: attrition.tex
*******************************************************************************/
use "$path/../Data/IE_Attrition.dta", clear

lab var B "Treat"
lab var exitattrit "At Exit"
lab var endattrit "At Endline"
lab var b_age "Age"
lab var b_mar "Married"
lab var b_div "Divorced"
lab var b_sing "Single"
lab var b_wid "Widowed"
lab var b_prim "Primary Ed."
lab var b_sec "Secondary Ed."
lab var b_p_prim "Father Primary Ed."
lab var b_p_sec "Father Secondary Ed."
lab var b_m_prim "Mother Primary Ed."
lab var b_m_sec "Mother Secondary Ed."
lab var b_employed "Employed"
lab var b_hh_size "HH Size"
lab var b_minors "Minors in HH"
lab var b_dexp_hh_w "Daily Expenditure HH"
lab var b_savings_w "Savings"
lab var b_remittances_w "Remittances"
lab var b_b0 "Own a Business"
lab var b_sales_last3_w "Sales - MB"
lab var b_srp_w "Profits - MB"
lab var b_ob_srp_w "Profits - OB"
lab var b_network "Network Size"
lab var b_loc_int "Locus - Internal"
lab var b_loc_po "Locus - PO"
lab var b_loc_chance "Locus - Chance"

******************************* Table File Code ********************************
eststo: reg exitattrit B $controlsBalance, robust
eststo: reg endattrit B $controlsBalance, robust

esttab est1 est2 using "$path/../Output/Tables/attrition.tex", replace nocons ///
prehead("\begin{table}[htbp]\footnotesize \centering \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \caption{Attrition \label{attrition}} \\ \begin{tabular}{l*{2}{c}} \toprule \toprule") ///
fragment ///
b(3) se(3) nostar ////
label scalars( "N Obs.") sfmt(3) ///
prefoot("\bottomrule") ///
postfoot("\bottomrule \bottomrule \multicolumn{3}{@{} p{0.6\textwidth}}{\footnotesize{\textit{Note:} For the marital status, the omitted dummy is the Widowed status.}} \end{tabular} \\ \end{table}")

est clear 

/*******************************************************************************
								BASELINE BALANCE SMS

			Table A3. Balance Table - SMS
			File name: balance_sms.tex
*******************************************************************************/
use "$path/../Data/IE_Submission.dta", clear
keep if sur_round == 1
keep id tmt
destring id,replace
tempfile tmt
save `tmt'

use "$path/../Data/IE_SMS.dta", clear
merge m:1 id using `tmt'
drop _merge

gen treatment=.
replace treatment=2 if tmt=="C"
replace treatment=1 if tmt=="B"

lab var count "No. of Responses"
lab var b_age "Age"
lab var b_mar "Married"
lab var b_div "Divorced"
lab var b_sing "Single"
lab var b_wid "Widowed"
lab var b_prim "Primary Ed."
lab var b_sec "Secondary Ed."
lab var b_p_prim "Father Primary Ed."
lab var b_p_sec "Father Secondary Ed."
lab var b_m_prim "Mother Primary Ed."
lab var b_m_sec "Mother Secondary Ed."
lab var b_employed "Employed"
lab var b_hh_size "HH Size"
lab var b_minors "Minors in HH"
lab var b_dexp_hh_w "Daily Expenditure HH"
lab var b_savings_w "Savings"
lab var b_remittances_w "Remittances"
lab var b_b0 "Own a Business"
lab var b_sales_last3_w "Sales - MB"
lab var b_srp_w "Profits - MB"
lab var b_ob_srp_w "Profits - OB"
lab var b_network "Network Size"
lab var b_loc_int "Locus - Internal"
lab var b_loc_po "Locus - PO"
lab var b_loc_chance "Locus - Chance"

******************************* Table File Code ********************************
cd "$path/../Output/Tables"

iebaltab count  b_age	b_mar	b_div	b_sing	b_wid	b_prim	b_sec	b_p_prim	b_p_sec	b_m_prim	b_m_sec	b_employed	b_hh_size	b_minors	b_dexp_hh_w	b_savings_w	b_remittances_w	b_b0	b_sales_last3_w	b_srp_w	b_ob_srp_w	b_network	b_loc_int	b_loc_po	b_loc_chance if event_date==1, replace ///
	grpvar(treatment) savet(balance_sms) ///
	stats(desc(sd) feq(p)) rowvarlabels starsno ///
	addnote("Mean baseline covariates by treatment group. Standard deviations are in parentheses. The last column reports p-values associated with T-tests of joint equality between the groups.") texnotewidth(0.9) grplabels(2 Control @ 1 Treatment) tblnon
	
cd "$path"
	
/*******************************************************************************
							ATTRITION TO SMS SURVEYS	
							
	Table B4. Attrition
	File name: attrition_sms.tex
*******************************************************************************/
use "$path/../Data/IE_SMS.dta", clear
collapse (count) Sales_Clean, by(id)
tempfile sms
save `sms'

use "$path/../Data/IE_Submission.dta", clear
keep if sur_round == 1
destring id,replace
merge 1:1 id using `sms'

replace B = 1 if tmt=="B"
drop _merge
replace Sales_Clean = 0 if Sales_Clean == .

lab var Sales_Clean "Times responding to the SMS survey"
lab var B "Treat"
lab var b_age "Age"
lab var b_mar "Married"
lab var b_div "Divorced"
lab var b_sing "Single"
lab var b_wid "Widowed"
lab var b_prim "Primary Ed."
lab var b_sec "Secondary Ed."
lab var b_p_prim "Father Primary Ed."
lab var b_p_sec "Father Secondary Ed."
lab var b_m_prim "Mother Primary Ed."
lab var b_m_sec "Mother Secondary Ed."
lab var b_employed "Employed"
lab var b_hh_size "HH Size"
lab var b_minors "Minors in HH"
lab var b_dexp_hh_w "Daily Expenditure HH"
lab var b_savings_w "Savings"
lab var b_remittances_w "Remittances"
lab var b_b0 "Own a Business"
lab var b_sales_last3_w "Sales - MB"
lab var b_srp_w "Profits - MB"
lab var b_ob_srp_w "Profits - OB"
lab var b_network "Network Size"
lab var b_loc_int "Locus - Internal"
lab var b_loc_po "Locus - PO"
lab var b_loc_chance "Locus - Chance"

eststo: reg Sales_Clean B $controlsBalance , robust

******************************* Table File Code ********************************
esttab est1 using "$path/../Output/Tables/attrition_sms.tex", replace nocons nomtitles ///
prehead("\begin{table}[htbp]\footnotesize \centering \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \caption{SMS Attrition \label{attritionsms}} \\ \begin{tabular}{l*{1}{c}} \toprule \toprule") ///
fragment ///
b(3) se(3) nostar ////
label scalars( "N Obs.") sfmt(3) ///
prefoot("\bottomrule") ///
postfoot("\bottomrule \bottomrule \multicolumn{2}{@{} p{0.35\textwidth}}{ \footnotesize{\textit{Notes}:}} \end{tabular} \\ \end{table}")

est clear 
restore

/*******************************************************************************
	CALCULATING SPILLOVER EFFECTS BY BUSINESS PARTNERSHIP LINKS - WEIGHTED
********************************************************************************
Average number of baseline business connections with treated women for women in 
the control group 
*******************************************************************************/
reg bpartnernetworkB_wt treat if sur_round==1 & tmt=="C"
	est sto CM_b
	
/*******************************************************************************
	  TREATMENT EFFECTS AND ADJUSTED TREATMENT EFFECTS ON BUSINESS OUTCOMES
								   EXTENSIVE MARGIN
	   
	Table A5. Adjusted Treatment Effects on Business Outcomes Extensive Margin
	File name: busout_adjust.tex
*******************************************************************************/
lab var b0 "Own a Business"
lab var bus_count "No. Businesses" 
lab var sales_last3_bin "$>0$ Sales" 
lab var srp_bin "$>0$ Profits"
lab var ob_srp_bin "$>0$ Profits"
lab var tot_srp_bin "$>0$ Profits"

******************************* Table File Code ********************************
* Start head ...................................................................
	cap texdoc close
	texdoc init "$path/../Output/Tables/busout_adjust.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize		
	tex \caption{Adjusted Treatment Effects on Business Outcomes Extensive Margin \label{busout:adjust}}
	tex \begin{tabular}{l*{7}{c}}			
	tex \toprule \toprule	
	tex &	\multicolumn{2}{c}{Business Creation}      &\multicolumn{2}{c}{Main Business}          &\multicolumn{1}{c}{\shortstack{Other\\Businesses}} &\multicolumn{1}{c}{All Businesses} &\multicolumn{1}{c}{}\\\cmidrule(lr){2-3}\cmidrule(lr){4-5}\cmidrule(lr){6-6}\cmidrule(lr){7-7}
	tex &	\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}&\multicolumn{1}{c}{(5)}&\multicolumn{1}{c}{(6)}&\multicolumn{1}{c}{(7)}\\
	tex &\multicolumn{1}{c}{Own a Business}&\multicolumn{1}{c}{No. Businesses}&\multicolumn{1}{c}{$>0$ Sales}&\multicolumn{1}{c}{$>0$ Profits}&\multicolumn{1}{c}{$>0$ Profits}&\multicolumn{1}{c}{$>0$ Profits}&\multicolumn{1}{c}{Index} \\ \midrule \\	
	
* End head .....................................................................

rwolf b0 bus_count sales_last3_bin srp_bin ob_srp_bin tot_srp_bin IND_extmargin if sur_round==2, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/7 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg b0 treat b_b0 $controls if sur_round==2
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"
	
	
reg bus_count treat b_bus_count $controls if sur_round==2
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg sales_last3_bin treat b_sales_last3_bin $controls if sur_round==2
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg srp_bin treat b_srp_bin $controls if sur_round==2
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg ob_srp_bin treat b_ob_srp_bin $controls if sur_round==2
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	


reg tot_srp_bin treat b_tot_srp_bin $controls if sur_round==2
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"	


reg IND_extmargin treat b_IND_extmargin $controls if sur_round==2
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n7 = "`obs'"
	global r7 = "`r2'"
est sto est7
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef7="`b'`star'"
glo se7="(\hspace{-0.1cm}`se')"	

	
// Spillover Regs	
reg b0 bpartnernetworkB_wt $controls b_b0 if sur_round==2 & treat==0
	est sto spill

suest est1 spill CM_b, vce(robust)
	
nlcom [est1_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q b0, c(1) e
		matrix Adj_qval = adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef1="`b'`star'"
glo ase1="(\hspace{-0.1cm}`se')"


reg bus_count bpartnernetworkB_wt $controls b_bus_count if sur_round==2 & treat==0, 
	est sto spill

suest est2 spill CM_b, vce(robust)
	
nlcom [est2_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q bus_count, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef2="`b'`star'"
glo ase2="(\hspace{-0.1cm}`se')"


reg sales_last3_bin bpartnernetworkB_wt $controls b_sales_last3_bin if sur_round==2 & treat==0, 
	est sto spill

suest est3 spill CM_b, vce(robust)
	
nlcom [est3_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q sales_last3_bin, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef3="`b'`star'"
glo ase3="(\hspace{-0.1cm}`se')"


reg srp_bin bpartnernetworkB_wt $controls b_srp_bin if sur_round==2 & treat==0, 
	est sto spill

suest est4 spill CM_b, vce(robust)
	
nlcom [est4_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q srp_bin, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef4="`b'`star'"
glo ase4="(\hspace{-0.1cm}`se')"


reg ob_srp_bin bpartnernetworkB_wt $controls b_ob_srp_bin if sur_round==2 & treat==0, 
	est sto spill

suest est5 spill CM_b, vce(robust)
	
nlcom [est5_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q ob_srp_bin, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef5="`b'`star'"
glo ase5="(\hspace{-0.1cm}`se')"


reg tot_srp_bin bpartnernetworkB_wt $controls b_tot_srp_bin if sur_round==2 & treat==0, 
	est sto spill

suest est6 spill CM_b, vce(robust)
	
nlcom [est6_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q tot_srp_bin, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef6="`b'`star'"
glo ase6="(\hspace{-0.1cm}`se')"


reg IND_extmargin bpartnernetworkB_wt $controls b_IND_extmargin if sur_round==2 & treat==0, 
	est sto spill

suest est7 spill CM_b, vce(robust)
	
nlcom [est7_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q tot_srp_bin, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef7="`b'`star'"
glo ase7="(\hspace{-0.1cm}`se')"

// Calculate Adjusted q-values
preserve
clear
matrix Adj_qval = Adj_qval'
svmat2 Adj_qval, names(col) rnames(Outcome)

rename pvalue pval
rename b coef

gen_qvals
matrix list Adj_qval

forval i=1/7 {
	local va`i':display %9.3f Adj_qval[`i',4] 
	di "`va`i''"
	global aqval`i' "[\hspace{-0.1cm}`va`i'']"
}
restore

// Control Means
summarize b0 if (sur_round==2 & tmt=="C")
	global CM1  : disp %9.3f r(mean)
summarize bus_count if (sur_round==2 & tmt=="C")
	global CM2  : disp %9.3f r(mean)
summarize sales_last3_bin if (sur_round==2 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize srp_bin if (sur_round==2 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize ob_srp_bin if (sur_round==2 & tmt=="C")
	global CM5  : disp %9.3f r(mean)
summarize tot_srp_bin if (sur_round==2 & tmt=="C")
	global CM6  : disp %9.3f r(mean)
summarize IND_extmargin if (sur_round==2 & tmt=="C")
	global CM7  : disp %9.3f r(mean)
	
	
disp " Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5	 & $acoef6	& $acoef7	"
disp "			& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	 & $acoef6	& $acoef7	"		
disp "			& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	& $aqval6	& $aqval7	"

********************************************************************************
// Midline
	
	tex \multicolumn{8}{c}{\textit{Panel A: Midline (6 months)}} \\\\[-1ex]
	tex Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5	 & $acoef6	& $acoef7	 \\
	tex				& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	 & $ase6	& $ase7	 \\
	tex				& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	 & $aqval6	& $aqval7	 \\
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5		 & $n6		& $n7	 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5		 & $CM6		& $CM7		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5		 & $r6		& $r7	 \\
	tex \midrule \\

********************************************************************************	
rwolf b0 bus_count sales_last3_bin srp_bin ob_srp_bin tot_srp_bin IND_extmargin if sur_round==3, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/7 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}
	
reg b0 treat b_b0 $controls if sur_round==3
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"
	
	
reg bus_count treat b_bus_count $controls if sur_round==3 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg sales_last3_bin treat b_sales_last3_bin $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg srp_bin treat b_srp_bin $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg ob_srp_bin treat b_ob_srp_bin $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	


reg tot_srp_bin treat b_tot_srp_bin $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"


reg IND_extmargin treat b_IND_extmargin $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n7 = "`obs'"
	global r7 = "`r2'"
est sto est7
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef7="`b'`star'"
glo se7="(\hspace{-0.1cm}`se')"

// Spillover Regs
reg b0 bpartnernetworkB_wt $controls b_b0 if sur_round==3 & treat==0, 
	est sto spill

suest est1 spill CM_b, vce(robust)
	
nlcom [est1_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q b0, c(1) e
		matrix Adj_qval = adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef1="`b'`star'"
glo ase1="(\hspace{-0.1cm}`se')"


reg bus_count bpartnernetworkB_wt $controls b_bus_count if sur_round==3 & treat==0, 
	est sto spill

suest est2 spill CM_b, vce(robust)
	
nlcom [est2_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q bus_count, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef2="`b'`star'"
glo ase2="(\hspace{-0.1cm}`se')"


reg sales_last3_bin bpartnernetworkB_wt $controls b_sales_last3_bin if sur_round==3 & treat==0, 
	est sto spill

suest est3 spill CM_b, vce(robust)
	
nlcom [est3_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q sales_last3_bin, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef3="`b'`star'"
glo ase3="(\hspace{-0.1cm}`se')"


reg srp_bin bpartnernetworkB_wt $controls b_srp_bin if sur_round==3 & treat==0, 
	est sto spill

suest est4 spill CM_b, vce(robust)
	
nlcom [est4_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q srp_bin, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef4="`b'`star'"
glo ase4="(\hspace{-0.1cm}`se')"


reg ob_srp_bin bpartnernetworkB_wt $controls b_ob_srp_bin if sur_round==3 & treat==0, 
	est sto spill

suest est5 spill CM_b, vce(robust)
	
nlcom [est5_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q ob_srp_bin, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef5="`b'`star'"
glo ase5="(\hspace{-0.1cm}`se')"


reg tot_srp_bin bpartnernetworkB_wt $controls b_tot_srp_bin if sur_round==3 & treat==0, 
	est sto spill

suest est6 spill CM_b, vce(robust)
	
nlcom [est6_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q tot_srp_bin, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef6="`b'`star'"
glo ase6="(\hspace{-0.1cm}`se')"


reg IND_extmargin bpartnernetworkB_wt $controls b_IND_extmargin if sur_round==3 & treat==0, 
	est sto spill

suest est7 spill CM_b, vce(robust)
	
nlcom [est7_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q tot_srp_bin, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef7="`b'`star'"
glo ase7="(\hspace{-0.1cm}`se')"

// Calculate Adjusted q-values
preserve
clear
matrix Adj_qval = Adj_qval'
svmat2 Adj_qval, names(col) rnames(Outcome)

rename pvalue pval
rename b coef

gen_qvals
matrix list Adj_qval

forval i=1/7 {
	local va`i':display %9.3f Adj_qval[`i',4] 
	di "`va`i''"
	global aqval`i' "[\hspace{-0.1cm}`va`i'']"
}
restore

// Control Means
summarize b0 if (sur_round==3 & tmt=="C")
	global CM1  : disp %9.3f r(mean)
summarize bus_count if (sur_round==3 & tmt=="C")
	global CM2  : disp %9.3f r(mean)
summarize sales_last3_bin if (sur_round==3 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize srp_bin if (sur_round==3 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize ob_srp_bin if (sur_round==3 & tmt=="C")
	global CM5  : disp %9.3f r(mean)
summarize tot_srp_bin if (sur_round==3 & tmt=="C")
	global CM6  : disp %9.3f r(mean)
summarize IND_extmargin if (sur_round==3 & tmt=="C")
	global CM7  : disp %9.3f r(mean)
	
	
disp " Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5	 & $acoef6 & $acoef7	"
disp "			& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	 & $acoef6	& $acoef7	"	
disp "			& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	& $aqval6	& $aqval7	"

// Endline
	
	tex \multicolumn{8}{c}{\textit{Panel B: Endline (18--24 months)}} \\\\[-1ex]
	tex Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5	 & $acoef6	& $acoef7	 \\
	tex				& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	 & $ase6	& $ase7	 \\
	tex				& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	 & $aqval6	& $aqval7	 \\
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5		 & $n6	& $n7		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5		 & $CM6	& $CM7		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5		 & $r6	& $r7		 \\
	
* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{7}{@{} p{1.09\textwidth}}{\footnotesize{\textit{Note:} We winsorize all sales and profit measures at the 99th percentile. Coefficients are ANCOVA estimates that control for the outcome at baseline, the respondent's location, marital status, household size, number of children, age, network size and level of education. Adjusted ITT shows effects adjusted for positive spillovers to the control group. We record revenues and profits for women without a business as zero to preserve the balance from randomization. Column (3) presents a dummy variable equal to 1 if the sales for the 3 days prior the survey are greater than 0, columns (4)--(6) present a dummy variable equal to 1 if the self-reported profits for the last month are greater than 0, for either the main business, other businesses or all businesses. We report White robust standard errors in parentheses. Index is an Anderson index of all outcomes using the swindex command in Stata.  Multiple hypothesis test q-values (computed following Anderson (2008)) are presented in brackets. Q-values include the same controls as above and are computed within pre-registered families of outcomes.}}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................
	
/*******************************************************************************
	  TREATMENT EFFECTS AND ADJUSTED TREATMENT EFFECTS ON BUSINESS OUTCOMES
								   	   
	Table A6. Adjusted Treatment Effects on Business Outcomes
	File name: busout_levels_adjust.tex
*******************************************************************************/
lab var sales_last3_w "Levels"
lab var srp_w "Levels"
lab var ob_srp_w "Levels"
lab var tot_srp_w "Levels"
lab var IND_intmargin "Index"

******************************* Table File Code ********************************
* Start head ...................................................................
	cap texdoc close
	texdoc init "$path/../Output/Tables/busout_levels_adjust.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize		
	tex \caption{Adjusted Treatment Effects on Business Outcomes: Intensive Margin \label{busout:levels:adjust}}
	tex \begin{tabular}{l*{5}{c}}			
	tex \toprule \toprule	
	tex &	\multicolumn{1}{c}{\shortstack{Main Business \\ Sales}}&\multicolumn{1}{c}{\shortstack{Main Business \\ Profits}}&\multicolumn{1}{c}{\shortstack{Other Businesses \\ Profits}}&\multicolumn{1}{c}{\shortstack{All Businesses \\ Profits}}&\multicolumn{1}{c}{}\\\cmidrule(lr){2-2}\cmidrule(lr){3-3}\cmidrule(lr){4-4}\cmidrule(lr){5-5}
	tex &	\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}&\multicolumn{1}{c}{(5)}\\
	tex &	\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Index}\\
	tex \midrule \\
	
* End head .....................................................................

rwolf sales_last3_w srp_w ob_srp_w tot_srp_w IND_intmargin if sur_round==2, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)
	
forval i=1/5 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg sales_last3_w treat b_sales_last3_w $controls if sur_round==2 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg srp_w treat b_srp_w $controls if sur_round==2 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg ob_srp_w treat b_ob_srp_w $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg tot_srp_w treat b_tot_srp_w $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"


reg IND_intmargin treat b_IND_extmargin $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"
	
// Spillover Regs
reg sales_last3_w bpartnernetworkB_wt $controls b_sales_last3_w if sur_round==2 & treat==0, 
	est sto spill

suest est1 spill CM_b, vce(robust)
	
nlcom [est1_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q sales_last3_w, c(1) e
		matrix Adj_qval = adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef1="`b'`star'"
glo ase1="(\hspace{-0.1cm}`se')"


reg srp_w bpartnernetworkB_wt $controls b_srp_w if sur_round==2 & treat==0, 
	est sto spill

suest est2 spill CM_b, vce(robust)
	
nlcom [est2_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q srp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef2="`b'`star'"
glo ase2="(\hspace{-0.1cm}`se')"


reg ob_srp_w bpartnernetworkB_wt $controls b_ob_srp_w if sur_round==2 & treat==0, 
	est sto spill

suest est3 spill CM_b, vce(robust)
	
nlcom [est3_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q ob_srp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef3="`b'`star'"
glo ase3="(\hspace{-0.1cm}`se')"


reg tot_srp_w bpartnernetworkB_wt $controls b_tot_srp_w if sur_round==2 & treat==0, 
	est sto spill

suest est4 spill CM_b, vce(robust)
	
nlcom [est4_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q tot_srp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef4="`b'`star'"
glo ase4="(\hspace{-0.1cm}`se')"


reg IND_intmargin bpartnernetworkB_wt $controls b_IND_intmargin if sur_round==2 & treat==0, 
	est sto spill

suest est5 spill CM_b, vce(robust)
	
nlcom [est5_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q tot_srp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef5="`b'`star'"
glo ase5="(\hspace{-0.1cm}`se')"

// Calculate Adjusted q-values
preserve
clear
matrix Adj_qval = Adj_qval'
svmat2 Adj_qval, names(col) rnames(Outcome)

rename pvalue pval
rename b coef

gen_qvals
matrix list Adj_qval

forval i=1/5 {
	local va`i':display %9.3f Adj_qval[`i',4] 
	di "`va`i''"
	global aqval`i' "[\hspace{-0.1cm}`va`i'']"
}
restore

// Control Means
summarize sales_last3_w if (sur_round==2 & tmt=="C")
	global CM1  : disp %9.2f r(mean)
summarize srp_w if (sur_round==2 & tmt=="C")
	global CM2  : disp %9.2f r(mean)
summarize ob_srp_w if (sur_round==2 & tmt=="C")
	global CM3  : disp %9.2f r(mean)
summarize tot_srp_w if (sur_round==2 & tmt=="C")
	global CM4  : disp %9.2f r(mean)
summarize IND_intmargin if (sur_round==2 & tmt=="C")
	global CM5  : disp %9.2f r(mean)

disp " Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	& $acoef5	 "
disp "			& $ase1		 & $ase2	 & $ase3	 & $ase4	& $ase5	 "
disp "			& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	& $aqval5   "
********************************************************************************
// Midline
	
	tex \multicolumn{6}{c}{\textit{Panel A: Midline (6 months)}} \\\\[-1ex]
	tex Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	& $acoef5	 \\
	tex				& $ase1		 & $ase2	 & $ase3	 & $ase4	& $ase5	 \\
	tex				& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	& $aqval5	 \\	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4	& $n5		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4	& $CM5		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4	& $r5		 \\
	tex \midrule \\

********************************************************************************	
rwolf sales_last3_w srp_w ob_srp_w tot_srp_w IND_intmargin if sur_round==3, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)
	
forval i=1/5 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg sales_last3_w treat b_sales_last3_w $controls if sur_round==3 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg srp_w treat b_srp_w $controls if sur_round==3 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg ob_srp_w treat b_ob_srp_w $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg tot_srp_w treat b_tot_srp_w $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"


reg IND_intmargin treat b_IND_intmargin $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"
	

// Spillover Regs
reg sales_last3_w bpartnernetworkB_wt $controls b_sales_last3_w if sur_round==3 & treat==0, 
	est sto spill

suest est1 spill CM_b, vce(robust)
	
nlcom [est1_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q sales_last3_w, c(1) e
		matrix Adj_qval = adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef1="`b'`star'"
glo ase1="(\hspace{-0.1cm}`se')"


reg srp_w bpartnernetworkB_wt $controls b_srp_w if sur_round==3 & treat==0, 
	est sto spill

suest est2 spill CM_b, vce(robust)
	
nlcom [est2_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q srp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef2="`b'`star'"
glo ase2="(\hspace{-0.1cm}`se')"


reg ob_srp_w bpartnernetworkB_wt $controls b_ob_srp_w if sur_round==3 & treat==0, 
	est sto spill

suest est3 spill CM_b, vce(robust)
	
nlcom [est3_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q ob_srp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef3="`b'`star'"
glo ase3="(\hspace{-0.1cm}`se')"


reg tot_srp_w bpartnernetworkB_wt $controls b_tot_srp_w if sur_round==3 & treat==0, 
	est sto spill

suest est4 spill CM_b, vce(robust)
	
nlcom [est4_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q tot_srp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef4="`b'`star'"
glo ase4="(\hspace{-0.1cm}`se')"


reg IND_intmargin bpartnernetworkB_wt $controls b_IND_intmargin if sur_round==3 & treat==0, 
	est sto spill

suest est5 spill CM_b, vce(robust)
	
nlcom [est5_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q tot_srp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef5="`b'`star'"
glo ase5="(\hspace{-0.1cm}`se')"

// Calculate Adjusted q-values
preserve
clear
matrix Adj_qval = Adj_qval'
svmat2 Adj_qval, names(col) rnames(Outcome)

rename pvalue pval
rename b coef

gen_qvals
matrix list Adj_qval

forval i=1/5 {
	local va`i':display %9.3f Adj_qval[`i',4] 
	di "`va`i''"
	global aqval`i' "[\hspace{-0.1cm}`va`i'']"
}
restore

// Control Means
summarize sales_last3_w if (sur_round==3 & tmt=="C")
	global CM1  : disp %9.2f r(mean)
summarize srp_w if (sur_round==3 & tmt=="C")
	global CM2  : disp %9.2f r(mean)
summarize ob_srp_w if (sur_round==3 & tmt=="C")
	global CM3  : disp %9.2f r(mean)
summarize tot_srp_w if (sur_round==3 & tmt=="C")
	global CM4  : disp %9.2f r(mean)
summarize IND_intmargin if (sur_round==3 & tmt=="C")
	global CM5  : disp %9.2f r(mean)

disp " Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	& $acoef5	 "
disp "			& $ase1		 & $ase2	 & $ase3	 & $ase4	& $ase5	 "
disp "			& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	& $aqval5	 "
********************************************************************************
// Endline
	
	tex \multicolumn{5}{c}{\textit{Panel B: Endline (18--24 Months)}} \\\\[-1ex]
	tex \addlinespace[5pt]	
	tex Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	& $acoef5	 \\
	tex				& $ase1		 & $ase2	 & $ase3	 & $ase4	& $ase5	 \\
	tex				& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	& $aqval5	 \\
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4	& $n5		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4	& $CM5		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4	& $r5		 \\

********************************************************************************

* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{6}{@{} p{0.90\textwidth}}{\footnotesize{ \textit{Note:} We winsorize all sales and profit measures at the 99th percentile. Coefficients are ANCOVA estimates that control for the outcome at baseline, the respondent's location, marital status, household size, number of children, age, network size and level of education. Adjusted ITT shows effects adjusted for positive spillovers to the control group. We report White robust standard errors in parentheses. Column (1) presents the reported sales for the 3 days prior  the survey, columns (2) to (4) present the self-reported profits for the last month for either the main business, other businesses, or all businesses. Values in columns marked with heading \textit{Levels} are values in UGX. Index is an Anderson index of all outcomes using the swindex command in Stata.  Multiple hypothesis test q-values (computed following Anderson (2008)) are presented in brackets. Q-values include the same controls as above and are computed within pre-registered families of outcomes.}}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................

/*******************************************************************************
 ADJUSTED TREATMENT EFFECTS ON RE-INVESTMENTS AND SAVINGS OUTCOMES
	   
	Table A7. Adjusted Treatment Effects on Re-Investments Outcomes
	File name: reinvout_adjust.tex
*******************************************************************************/
lab var savings_w "Levels"
lab var ba_val_w "Levels"
lab var ob_inv_w "Levels"
lab var IND_savings "Index"

******************************* Table File Code ********************************
* Start head ...................................................................
	cap texdoc close
	texdoc init "$path/../Output/Tables/reinvout_adjust.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize		
	tex \caption{Adjusted Treatment Effects on Re-Investments Outcomes \label{reinvout:adjust}}
	tex \begin{tabular}{l*{4}{c}}			
	tex \toprule \toprule	
	tex &\multicolumn{1}{c}{Savings}                &\multicolumn{1}{c}{Business Assests}       &\multicolumn{1}{c}{\shortstack{Investments in \\ Other Businesses}} &\multicolumn{1}{c}{}\\\cmidrule(lr){2-2}\cmidrule(lr){3-3}\cmidrule(lr){4-4}
	tex &\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}\\
	tex &\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Index} \\ \midrule \\

* End head .....................................................................

rwolf savings_w ba_val_w ob_inv_w IND_savings if sur_round==2, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)
forval i=1/4 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg savings_w treat b_savings_w $controls if sur_round==2 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg ba_val_w treat b_ba_val_w $controls if sur_round==2 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(`se')"


reg ob_inv_w treat b_ob_inv_w $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"


reg IND_savings treat b_IND_savings $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	

// Spillover Regs
reg savings_w bpartnernetworkB_wt $controls b_savings_w if sur_round==2 & treat==0, 
	est sto spill

suest est1 spill CM_b, vce(robust)
	
nlcom [est1_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q savings_w, c(1) e
		matrix Adj_qval = adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef1="`b'`star'"
glo ase1="(\hspace{-0.1cm}`se')"


reg ba_val_w bpartnernetworkB_wt $controls b_ba_val_w if sur_round==2 & treat==0, 
	est sto spill

suest est2 spill CM_b, vce(robust)
	
nlcom [est2_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q ba_val_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef2="`b'`star'"
glo ase2="(`se')"


reg ob_inv_w bpartnernetworkB_wt $controls b_ob_inv_w if sur_round==2 & treat==0, 
	est sto spill

suest est3 spill CM_b, vce(robust)
	
nlcom [est3_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q ob_inv_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef3="`b'`star'"
glo ase3="(\hspace{-0.1cm}`se')"


reg IND_savings bpartnernetworkB_wt $controls b_IND_savings if sur_round==2 & treat==0, 
	est sto spill

suest est4 spill CM_b, vce(robust)
	
nlcom [est4_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q ob_inv_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef4="`b'`star'"
glo ase4="(\hspace{-0.1cm}`se')"

// Calculate Adjusted q-values
preserve
clear
matrix Adj_qval = Adj_qval'
svmat2 Adj_qval, names(col) rnames(Outcome)

rename pvalue pval
rename b coef

gen_qvals
matrix list Adj_qval

forval i=1/4 {
	local va`i':display %9.3f Adj_qval[`i',4] 
	di "`va`i''"
	global aqval`i' "[\hspace{-0.1cm}`va`i'']"
}
restore

// Control Means
summarize savings_w if (sur_round==2 & tmt=="C")
	global CM1  : disp %12.2f r(mean)
summarize ba_val_w if (sur_round==2 & tmt=="C")
	global CM2  : disp %12.2f r(mean)
summarize ob_inv_w if (sur_round==2 & tmt=="C")
	global CM3  : disp %12.2f r(mean)
summarize IND_savings if (sur_round==2 & tmt=="C")
	global CM4  : disp %12.2f r(mean)

disp " Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	& $acoef4	 "
disp "			& $ase1		 & $ase2	 & $ase3	& $ase4	 "
disp "			& $aqval1	 & $aqval2	 & $aqval3	& $aqval4	 "

********************************************************************************
// Midline
	
	tex \multicolumn{5}{c}{\textit{Panel A: Midline (6 months)}} \\\\[-1ex]
	tex Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	& $acoef4	 \\
	tex				& $ase1		 & $ase2	 & $ase3	& $ase4	 \\
	tex				& $aqval1	 & $aqval2	 & $aqval3	& $aqval4	 \\	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3	& $n4		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3	& $CM4		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3	& $r4		 \\
	tex \midrule \\

********************************************************************************

rwolf savings_w ba_val_w ob_inv_w IND_savings if sur_round==3, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)
forval i=1/4 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg savings_w treat b_savings_w $controls if sur_round==3 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg ba_val_w treat b_ba_val_w $controls if sur_round==3 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(`se')"


reg ob_inv_w treat b_ob_inv_w $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"


reg IND_savings treat b_IND_savings $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	

// Spillover Regs
reg savings_w bpartnernetworkB_wt $controls b_savings_w if sur_round==3 & treat==0, 
	est sto spill

suest est1 spill CM_b, vce(robust)
	
nlcom [est1_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q savings_w, c(1) e
		matrix Adj_qval = adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef1="`b'`star'"
glo ase1="(\hspace{-0.1cm}`se')"


reg ba_val_w bpartnernetworkB_wt $controls b_ba_val_w if sur_round==3 & treat==0, 
	est sto spill

suest est2 spill CM_b, vce(robust)
	
nlcom [est2_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q ba_val_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef2="`b'`star'"
glo ase2="(`se')"


reg ob_inv_w bpartnernetworkB_wt $controls b_ob_inv_w if sur_round==3 & treat==0, 
	est sto spill

suest est3 spill CM_b, vce(robust)
	
nlcom [est3_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q ob_inv_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef3="`b'`star'"
glo ase3="(\hspace{-0.1cm}`se')"


reg IND_savings bpartnernetworkB_wt $controls b_IND_savings if sur_round==3 & treat==0, 
	est sto spill

suest est4 spill CM_b, vce(robust)
	
nlcom [est4_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q ob_inv_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef4="`b'`star'"
glo ase4="(\hspace{-0.1cm}`se')"

// Calculate Adjusted q-values
preserve
clear
matrix Adj_qval = Adj_qval'
svmat2 Adj_qval, names(col) rnames(Outcome)

rename pvalue pval
rename b coef

gen_qvals
matrix list Adj_qval

forval i=1/4 {
	local va`i':display %9.3f Adj_qval[`i',4] 
	di "`va`i''"
	global aqval`i' "[\hspace{-0.1cm}`va`i'']"
}
restore

// Control Means
summarize savings_w if (sur_round==3 & tmt=="C")
	global CM1  : disp %12.2f r(mean)
summarize ba_val_w if (sur_round==3 & tmt=="C")
	global CM2  : disp %12.2f r(mean)
summarize ob_inv_w if (sur_round==3 & tmt=="C")
	global CM3  : disp %12.2f r(mean)
summarize IND_savings if (sur_round==3 & tmt=="C")
	global CM4  : disp %12.2f r(mean)

disp " Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	& $acoef4	 "
disp "			& $ase1		 & $ase2	 & $ase3	& $ase4	 "
disp "			& $aqval1	 & $aqval2	 & $aqval3	& $aqval4	 "

********************************************************************************
// Endline
	
	tex \multicolumn{4}{c}{\textit{Panel B: Endline (18--24 Months)}} \\\\[-1ex]
	tex Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	& $acoef4	 \\
	tex				& $ase1		 & $ase2	 & $ase3	& $ase4	 \\
	tex				& $aqval1	 & $aqval2	 & $aqval3	& $aqval4	 \\
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3	& $n4		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		& $CM4	 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		& $r4	 \\

********************************************************************************

* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{5}{@{} p{0.74\textwidth}}{\footnotesize{ \textit{Note:} We winsorize all savings and investment measures at the 99th percentile. Coefficients are ANCOVA estimates that control for the outcome at baseline, the respondent's location, marital status, household size, number of children, age, network size and level of education. Adjusted ITT shows effects adjusted for positive spillovers to the control group. Savings is the total amount held in all financial savings instruments. Business assets is the estimated monetary value of all assets held in the main business. Investments in other businesses is the total estimated monetary value of all investments in businesses other than the main business in the last 6 months. Values in columns marked with heading \textit{Levels} are values in UGX. We report White robust standard errors in parentheses. Index is an Anderson index of all outcomes using the swindex command in Stata. Multiple hypothesis test q-values (computed following Anderson (2008)) are presented in brackets. Q-values include the same controls as above and are computed within pre-registered families of outcomes.}}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................


/*******************************************************************************
	 ADJUSTED TREATMENT EFFECTS ON POSSIBLE MECHANISMS
	   
	Table A8. Mechanisms of Adjusted Treatment Effects
	File name: mechout_adjust.tex
*******************************************************************************/
lab var b_track "Tracking"
lab var pric_mgt "Price Mgmt."
lab var wk_hrs "Work Hours"
lab var goal "Goal Setting"
lab var grit "Grit"
lab var loc_int "Internal"
lab var loc_po "PO"
lab var loc_chance "Chance" 
lab var income_asp_w "Levels" 
lab var IND_skills "Index"

******************************* Table File Code ********************************
* Start head ...................................................................
	cap texdoc close
	texdoc init "$path/../Output/Tables/mechout_adjust.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize		
	tex \caption{Adjusted Treatment Effects: Skills \label{mechout:adjust}}
	tex \begin{tabular}{l*{10}{c}}			
	tex \toprule \toprule	
	tex &	\multicolumn{4}{c}{ }	&	\multicolumn{1}{c}{ }&\multicolumn{3}{c}{Locus of Control}	&	\multicolumn{1}{c}{Income Aspirations} &	\multicolumn{1}{c}{}     \\\cmidrule(lr){7-9}\cmidrule(lr){10-10}
	tex &	\multicolumn{1}{c}{(1)}	&	\multicolumn{1}{c}{(2)}	&	\multicolumn{1}{c}{(3)}	&	\multicolumn{1}{c}{(4)}	&	\multicolumn{1}{c}{(5)}	&	\multicolumn{1}{c}{(6)}	&	\multicolumn{1}{c}{(7)}	&	\multicolumn{1}{c}{(8)}	&	\multicolumn{1}{c}{(9)}	&	\multicolumn{1}{c}{(10)}\\
	tex &	\multicolumn{1}{c}{Tracking}	&	\multicolumn{1}{c}{Price Mgmt.}	&	\multicolumn{1}{c}{Work Hours}	&	\multicolumn{1}{c}{Goal Setting}	&	\multicolumn{1}{c}{Grit}	&	\multicolumn{1}{c}{Internal}	&	\multicolumn{1}{c}{PO}	&	\multicolumn{1}{c}{Chance}	&	\multicolumn{1}{c}{Levels} &	\multicolumn{1}{c}{Index}\\ \midrule \\

* End head .....................................................................

rwolf b_track pric_mgt wk_hrs goal grit loc_int loc_po loc_chance income_asp_w IND_skills if sur_round==2, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/10 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg b_track treat b_b_track $controls if sur_round==2 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg pric_mgt treat b_pric_mgt $controls if sur_round==2 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg wk_hrs treat b_wk_hrs $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg goal treat b_goal $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg grit treat b_grit $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	


reg loc_int treat b_loc_int $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"

reg loc_po treat b_loc_po $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n7 = "`obs'"
	global r7 = "`r2'"
est sto est7
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef7="`b'`star'"
glo se7="(\hspace{-0.1cm}`se')"
	

reg loc_chance treat b_loc_chance $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n8 = "`obs'"
	global r8 = "`r2'"
est sto est8
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef8="`b'`star'"
glo se8="(\hspace{-0.1cm}`se')"
	
	
reg income_asp_w treat b_income_asp_w $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n9 = "`obs'"
	global r9 = "`r2'"
est sto est9
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef9="`b'`star'"
glo se9="(\hspace{-0.1cm}`se')"	


reg IND_skills treat b_IND_skills $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n10 = "`obs'"
	global r10 = "`r2'"
est sto est10
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef10="`b'`star'"
glo se10="(\hspace{-0.1cm}`se')"	

// Spillover Regs
reg b_track bpartnernetworkB_wt $controls b_b_track if sur_round==2 & treat==0, 
	est sto spill

suest est1 spill CM_b, vce(robust)
	
nlcom [est1_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q b_track, c(1) e
		matrix Adj_qval = adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef1="`b'`star'"
glo ase1="(\hspace{-0.1cm}`se')"


reg pric_mgt bpartnernetworkB_wt $controls b_pric_mgt if sur_round==2 & treat==0, 
	est sto spill

suest est2 spill CM_b, vce(robust)
	
nlcom [est2_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q pric_mgt, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef2="`b'`star'"
glo ase2="(\hspace{-0.1cm}`se')"


reg wk_hrs bpartnernetworkB_wt $controls b_wk_hrs if sur_round==2 & treat==0, 
	est sto spill

suest est3 spill CM_b, vce(robust)
	
nlcom [est3_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q wk_hrs, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef3="`b'`star'"
glo ase3="(\hspace{-0.1cm}`se')"


reg goal bpartnernetworkB_wt $controls b_goal if sur_round==2 & treat==0, 
	est sto spill

suest est4 spill CM_b, vce(robust)
	
nlcom [est4_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q goal, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef4="`b'`star'"
glo ase4="(\hspace{-0.1cm}`se')"


reg grit bpartnernetworkB_wt $controls b_grit if sur_round==2 & treat==0, 
	est sto spill

suest est5 spill CM_b, vce(robust)
	
nlcom [est5_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q grit, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef5="`b'`star'"
glo ase5="(\hspace{-0.1cm}`se')"


reg loc_int bpartnernetworkB_wt $controls b_loc_int if sur_round==2 & treat==0, 
	est sto spill

suest est6 spill CM_b, vce(robust)
	
nlcom [est6_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q loc_int, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef6="`b'`star'"
glo ase6="(\hspace{-0.1cm}`se')"


reg loc_po bpartnernetworkB_wt $controls b_loc_po if sur_round==2 & treat==0, 
	est sto spill

suest est7 spill CM_b, vce(robust)
	
nlcom [est7_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q loc_po, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef7="`b'`star'"
glo ase7="(\hspace{-0.1cm}`se')"


reg loc_chance bpartnernetworkB_wt $controls b_loc_chance if sur_round==2 & treat==0, 
	est sto spill

suest est8 spill CM_b, vce(robust)
	
nlcom [est8_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q loc_chance, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef8="`b'`star'"
glo ase8="(\hspace{-0.1cm}`se')"


reg income_asp_w bpartnernetworkB_wt $controls b_income_asp_w if sur_round==2 & treat==0, 
	est sto spill

suest est9 spill CM_b, vce(robust)
	
nlcom [est9_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q income_asp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef9="`b'`star'"
glo ase9="(\hspace{-0.1cm}`se')"


reg IND_skills bpartnernetworkB_wt $controls b_IND_skills if sur_round==2 & treat==0, 
	est sto spill

suest est10 spill CM_b, vce(robust)
	
nlcom [est10_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q income_asp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef10="`b'`star'"
glo ase10="(\hspace{-0.1cm}`se')"

// Calculate Adjusted q-values
preserve
clear
matrix Adj_qval = Adj_qval'
svmat2 Adj_qval, names(col) rnames(Outcome)

rename pvalue pval
rename b coef

gen_qvals
matrix list Adj_qval

forval i=1/10 {
	local va`i':display %9.3f Adj_qval[`i',4] 
	di "`va`i''"
	global aqval`i' "[\hspace{-0.1cm}`va`i'']"
}
restore

// Control Means
summarize b_track if (sur_round==2 & tmt=="C")
	global CM1  : disp %9.3f r(mean)
summarize pric_mgt if (sur_round==2 & tmt=="C")
	global CM2  : disp %9.3f r(mean)
summarize wk_hrs if (sur_round==2 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize goal if (sur_round==2 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize grit if (sur_round==2 & tmt=="C")
	global CM5  : disp %9.3f r(mean)
summarize loc_int if (sur_round==2 & tmt=="C")
	global CM6  : disp %9.3f r(mean)
summarize loc_po if (sur_round==2 & tmt=="C")
	global CM7  : disp %9.3f r(mean)
summarize loc_chance if (sur_round==2 & tmt=="C")
	global CM8  : disp %9.3f r(mean)
summarize income_asp_w if (sur_round==2 & tmt=="C")
	global CM9  : disp %12.2f r(mean)
summarize IND_skills if (sur_round==2 & tmt=="C")
	global CM10  : disp %12.2f r(mean)
	
disp " Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5	 & $acoef6	&  $acoef7   & $acoef8    & $acoef9	& $acoef10	"
disp "			& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	 & $ase6	&  $ase7   & $ase8    & $ase9	& $ase10	"
disp "		& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	& $aqval6	&  $aqval7   & $aqval8    & $aqval9	& $aqval10	"

********************************************************************************
// Midline
	
	tex \multicolumn{11}{c}{\textit{Panel A: Midline (6 months)}} \\\\[-1ex]
	tex Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5	 & $acoef6	 &  $acoef7   & $acoef8  & $acoef9	& $acoef10	 \\
	tex				& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	 & $ase6	 &  $ase7     & $ase8    & $ase9	& $ase10	 \\
	tex				& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	 & $aqval6	 &  $aqval7   & $aqval8    & $aqval9	& $aqval10	 \\	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5		 & $n6	 & $n7		 & $n8		 & $n9	& $n10			 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5		 & $CM6	 & $CM7		 & $CM8		 & $CM9	& $CM10			 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5		 & $r6	 & $r7		 & $r8		 & $r9	& $r10			 \\
	tex \midrule \\

********************************************************************************

rwolf b_track pric_mgt wk_hrs goal grit loc_int loc_po loc_chance income_asp_w IND_skills if sur_round==3, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/10 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg b_track treat b_b_track $controls if sur_round==3 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg pric_mgt treat b_pric_mgt $controls if sur_round==3 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg wk_hrs treat b_wk_hrs $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg goal treat b_goal $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg grit treat b_grit $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	


reg loc_int treat b_loc_int $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"

reg loc_po treat b_loc_po $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n7 = "`obs'"
	global r7 = "`r2'"
est sto est7
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef7="`b'`star'"
glo se7="(\hspace{-0.1cm}`se')"
	

reg loc_chance treat b_loc_chance $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n8 = "`obs'"
	global r8 = "`r2'"
est sto est8
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef8="`b'`star'"
glo se8="(\hspace{-0.1cm}`se')"
	
	
reg income_asp_w treat b_income_asp_w $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n9 = "`obs'"
	global r9 = "`r2'"
est sto est9
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef9="`b'`star'"
glo se9="(\hspace{-0.1cm}`se')"	


reg IND_skills treat b_IND_skills $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n10 = "`obs'"
	global r10 = "`r2'"
est sto est10
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef10="`b'`star'"
glo se10="(\hspace{-0.1cm}`se')"	


// Spillover Regs
reg b_track bpartnernetworkB_wt $controls b_b_track if sur_round==3 & treat==0, 
	est sto spill

suest est1 spill CM_b, vce(robust)
	
nlcom [est1_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q b_track, c(1) e
		matrix Adj_qval = adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef1="`b'`star'"
glo ase1="(\hspace{-0.1cm}`se')"


reg pric_mgt bpartnernetworkB_wt $controls b_pric_mgt if sur_round==3 & treat==0, 
	est sto spill

suest est2 spill CM_b, vce(robust)
	
nlcom [est2_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q pric_mgt, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef2="`b'`star'"
glo ase2="(\hspace{-0.1cm}`se')"


reg wk_hrs bpartnernetworkB_wt $controls b_wk_hrs if sur_round==3 & treat==0, 
	est sto spill

suest est3 spill CM_b, vce(robust)
	
nlcom [est3_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q wk_hrs, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef3="`b'`star'"
glo ase3="(\hspace{-0.1cm}`se')"


reg goal bpartnernetworkB_wt $controls b_goal if sur_round==3 & treat==0, 
	est sto spill

suest est4 spill CM_b, vce(robust)
	
nlcom [est4_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q goal, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef4="`b'`star'"
glo ase4="(\hspace{-0.1cm}`se')"


reg grit bpartnernetworkB_wt $controls b_grit if sur_round==3 & treat==0, 
	est sto spill

suest est5 spill CM_b, vce(robust)
	
nlcom [est5_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q grit, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef5="`b'`star'"
glo ase5="(\hspace{-0.1cm}`se')"


reg loc_int bpartnernetworkB_wt $controls b_loc_int if sur_round==3 & treat==0, 
	est sto spill

suest est6 spill CM_b, vce(robust)
	
nlcom [est6_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q loc_int, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef6="`b'`star'"
glo ase6="(\hspace{-0.1cm}`se')"


reg loc_po bpartnernetworkB_wt $controls b_loc_po if sur_round==3 & treat==0, 
	est sto spill

suest est7 spill CM_b, vce(robust)
	
nlcom [est7_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q loc_po, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef7="`b'`star'"
glo ase7="(\hspace{-0.1cm}`se')"


reg loc_chance bpartnernetworkB_wt $controls b_loc_chance if sur_round==3 & treat==0, 
	est sto spill

suest est8 spill CM_b, vce(robust)
	
nlcom [est8_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q loc_chance, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef8="`b'`star'"
glo ase8="(\hspace{-0.1cm}`se')"


reg income_asp_w bpartnernetworkB_wt $controls b_income_asp_w if sur_round==3 & treat==0, 
	est sto spill

suest est9 spill CM_b, vce(robust)
	
nlcom [est9_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q income_asp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef9="`b'`star'"
glo ase9="(\hspace{-0.1cm}`se')"

reg IND_skills bpartnernetworkB_wt $controls b_IND_skills if sur_round==3 & treat==0, 
	est sto spill

suest est10 spill CM_b, vce(robust)
	
nlcom [est10_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q income_asp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef10="`b'`star'"
glo ase10="(\hspace{-0.1cm}`se')"


// Calculate Adjusted q-values
preserve
clear
matrix Adj_qval = Adj_qval'
svmat2 Adj_qval, names(col) rnames(Outcome)

rename pvalue pval
rename b coef

gen_qvals
matrix list Adj_qval

forval i=1/10 {
	local va`i':display %9.3f Adj_qval[`i',4] 
	di "`va`i''"
	global aqval`i' "[\hspace{-0.1cm}`va`i'']"
}
restore

// Control Means
summarize b_track if (sur_round==3 & tmt=="C")
	global CM1  : disp %9.3f r(mean)
summarize pric_mgt if (sur_round==3 & tmt=="C")
	global CM2  : disp %9.3f r(mean)
summarize wk_hrs if (sur_round==3 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize goal if (sur_round==3 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize grit if (sur_round==3 & tmt=="C")
	global CM5  : disp %9.3f r(mean)
summarize loc_int if (sur_round==3 & tmt=="C")
	global CM6  : disp %9.3f r(mean)
summarize loc_po if (sur_round==3 & tmt=="C")
	global CM7  : disp %9.3f r(mean)
summarize loc_chance if (sur_round==3 & tmt=="C")
	global CM8  : disp %9.3f r(mean)
summarize income_asp_w if (sur_round==3 & tmt=="C")
	global CM9  : disp %12.2f r(mean)
summarize IND_skills if (sur_round==3 & tmt=="C")
	global CM10  : disp %12.2f r(mean)


disp " Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5	 & $acoef6	&  $acoef7   & $acoef8    & $acoef9	& $acoef10	"
disp "			& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	 & $ase6	&  $ase7   & $ase8    & $ase9	& $ase10	"
disp "		& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	& $aqval6	&  $aqval7   & $aqval8    & $aqval9	& $aqval10	"

********************************************************************************
// Endline
	
	tex \multicolumn{10}{c}{\textit{Panel B: Endline (18--24 Months)}} \\\\[-1ex]
	tex Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5	 & $acoef6	 &  $acoef7   & $acoef8    & $acoef9	& $acoef10 \\
	tex				& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	 & $ase6	 &  $ase7	  & $ase8	   & $ase9	& $ase10	 \\
	tex				& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	 & $aqval6	 &  $aqval7   & $aqval8    & $aqval9	& $aqval10	 \\		
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5		 & $n6	 & $n7		 & $n8		 & $n9	& $n10		 	 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5		 & $CM6	 & $CM7		 & $CM8		 & $CM9	& $CM10		 	 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5		 & $r6	 & $r7		 & $r8		 & $r9	& $r10		     \\

********************************************************************************	
	
* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{11}{@{} p{1.35\textwidth}}{\footnotesize{ \textit{Note:} Coefficients are ANCOVA estimates that control for the outcome at baseline, the respondent's location, marital status, household size, number of children, age, network size and level of education. Adjusted ITT shows effects adjusted for positive spillovers to the control group. Tracking combines multiple questions about record keeping for the business with a maximum value of 3. Price management combines multiple questions about setting prices, running promotions, comparing prices with competitors, and negotiating for better prices with suppliers with a maximum value of 4. Goal setting combines multiple questions about setting goals for the business over various time horizons with a maximum value of 3. Work hours is the number of hours the respondent typically works in her main business. Our measures of grit follow \textcite{duckworth:grit:2007} and \textcite{duckworth:development:2009}. We draw our locus of control measures from \textcite{levenson:multidimensional:1973}. Internal, PO, and Chance is the dimension of the locus of control score. Positive values for Internal, PO and Chance provide evidence of improvements in locus of control measures independent of type. We winsorize the income aspirations variable at the 99th percentile. Values in columns marked with heading \textit{Levels} are values in UGX. We report White robust standard errors in parentheses. Index is an Anderson index of all outcomes using the swindex command in Stata.  Multiple hypothesis test q-values (computed following Anderson (2008)) are presented in brackets. Q-values include the same controls as above and are computed within pre-registered families of outcomes.}}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................

/*******************************************************************************
	  ADJUSTED TREATMENT EFFECTS ON HOUSEHOLD OUTCOMES
	   
	Table A10. Adjusted Treatment Effects on Household Outcomes
	File name: hhout_adjust.tex
*******************************************************************************/
lab var dexp_hh_w "\shortstack{HH \\ Levels}"
lab var dexp_w "\shortstack{Participant \\ Levels}"
lab var mue_w "MUE"
lab var food_ins "\shortstack{Food \\ Insecurity}"
lab var remittances_w "Levels"
lab var IND_hh "Index"

******************************* Table File Code ********************************
* Start head ...................................................................
	cap texdoc close
	texdoc init "$path/../Output/Tables/hhout_adjust.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize		
	tex \caption{Adjusted Treatment Effects on Household Outcomes \label{hhout:adjust}}
	tex \begin{tabular}{l*{6}{c}}			
	tex \toprule \toprule	
	tex &	\multicolumn{2}{c}{Daily Expenditure}	&	\multicolumn{2}{c}{}	&	\multicolumn{1}{c}{Remittances}	&	\multicolumn{1}{c}{}	\\\cmidrule(lr){2-3}\cmidrule(lr){4-5}\cmidrule(lr){6-6}
	tex &	\multicolumn{1}{c}{(1)}	&	\multicolumn{1}{c}{(2)}	&	\multicolumn{1}{c}{(3)}	&	\multicolumn{1}{c}{(4)}	&	\multicolumn{1}{c}{(5)}	&	\multicolumn{1}{c}{(6)}	\\
	tex &	\multicolumn{1}{c}{\shortstack{HH \\ Levels}}		&	\multicolumn{1}{c}{\shortstack{Participant \\ Levels}}	&	\multicolumn{1}{c}{MUE}	&	\multicolumn{1}{c}{\shortstack{Food \\ Insecurity}}&	\multicolumn{1}{c}{Levels}	&	\multicolumn{1}{c}{Index} \\ \midrule \\

* End head .....................................................................

rwolf dexp_hh_w  dexp_w mue_w food_ins  remittances_w IND_hh if sur_round==2, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/6 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg dexp_hh_w treat b_dexp_hh_w $controls if sur_round==2 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg dexp_w treat b_dexp_w $controls if sur_round==2 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg mue_w treat b_mue_w $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg food_ins treat b_food_ins $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg remittances_w treat b_remittances_w $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	

reg IND_hh treat b_IND_hh $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"	


// Spillover Regs
reg dexp_hh_w bpartnernetworkB_wt $controls b_dexp_hh_w if sur_round==2 & treat==0, 
	est sto spill

suest est1 spill CM_b, vce(robust)
	
nlcom [est1_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q dexp_hh_w, c(1) e
		matrix Adj_qval = adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef1="`b'`star'"
glo ase1="(\hspace{-0.1cm}`se')"


reg dexp_w bpartnernetworkB_wt $controls b_dexp_w if sur_round==2 & treat==0, 
	est sto spill

suest est2 spill CM_b, vce(robust)
	
nlcom [est2_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q dexp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef2="`b'`star'"
glo ase2="(\hspace{-0.1cm}`se')"


reg mue_w bpartnernetworkB_wt $controls b_mue_w if sur_round==2 & treat==0, 
	est sto spill

suest est3 spill CM_b, vce(robust)
	
nlcom [est3_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q mue_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef3="`b'`star'"
glo ase3="(\hspace{-0.1cm}`se')"


reg food_ins bpartnernetworkB_wt $controls b_food_ins if sur_round==2 & treat==0, 
	est sto spill

suest est4 spill CM_b, vce(robust)
	
nlcom [est4_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q food_ins, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef4="`b'`star'"
glo ase4="(\hspace{-0.1cm}`se')"


reg remittances_w bpartnernetworkB_wt $controls b_remittances_w if sur_round==2 & treat==0, 
	est sto spill

suest est5 spill CM_b, vce(robust)
	
nlcom [est5_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q remittances_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef5="`b'`star'"
glo ase5="(\hspace{-0.1cm}`se')"


reg IND_hh bpartnernetworkB_wt $controls b_IND_hh if sur_round==2 & treat==0, 
	est sto spill

suest est6 spill CM_b, vce(robust)
	
nlcom [est6_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q remittances_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef6="`b'`star'"
glo ase6="(\hspace{-0.1cm}`se')"

// Calculate Adjusted q-values
preserve
clear
matrix Adj_qval = Adj_qval'
svmat2 Adj_qval, names(col) rnames(Outcome)

rename pvalue pval
rename b coef

gen_qvals
matrix list Adj_qval

forval i=1/6 {
	local va`i':display %9.3f Adj_qval[`i',4] 
	di "`va`i''"
	global aqval`i' "[\hspace{-0.1cm}`va`i'']"
}
restore

// Control Means
summarize dexp_hh_w if (sur_round==2 & tmt=="C")
	global CM1  : disp %9.2f r(mean)
summarize dexp_w if (sur_round==2 & tmt=="C")
	global CM2  : disp %9.2f r(mean)
summarize mue_w if (sur_round==2 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize food_ins if (sur_round==2 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize remittances_w if (sur_round==2 & tmt=="C")
	global CM5  : disp %9.2f r(mean)
summarize IND_hh if (sur_round==2 & tmt=="C")
	global CM6  : disp %9.2f r(mean)


disp " Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5	& $acoef6	 "
disp "			& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	& $ase6	 "
disp "			& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	& $aqval6	 "

********************************************************************************
// Midline
	
	tex \multicolumn{6}{c}{\textit{Panel A: Midline (6 months)}} \\\\[-1ex]
	tex Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5	& $acoef6	 \\
	tex				& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	& $ase6	 \\
	tex				& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	& $aqval6	 \\
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5	& $n6		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5	& $CM6		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5	& $r6		 \\
	tex \midrule \\

********************************************************************************

rwolf dexp_hh_w dexp_w mue_w food_ins remittances_w IND_hh if sur_round==3, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/6 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg dexp_hh_w treat b_dexp_hh_w $controls if sur_round==3 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg dexp_w treat b_dexp_w $controls if sur_round==3 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg mue_w treat b_mue_w $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg food_ins treat b_food_ins $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg remittances_w treat b_remittances_w $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	


reg IND_hh treat b_IND_hh $controls if sur_round==3, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"	


// Spillover Regs
reg dexp_hh_w bpartnernetworkB_wt $controls b_dexp_hh_w if sur_round==3 & treat==0, 
	est sto spill

suest est1 spill CM_b, vce(robust)
	
nlcom [est1_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q dexp_hh_w, c(1) e
		matrix Adj_qval = adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef1="`b'`star'"
glo ase1="(\hspace{-0.1cm}`se')"


reg dexp_w bpartnernetworkB_wt $controls b_dexp_w if sur_round==3 & treat==0, 
	est sto spill

suest est2 spill CM_b, vce(robust)
	
nlcom [est2_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q dexp_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef2="`b'`star'"
glo ase2="(\hspace{-0.1cm}`se')"


reg mue_w bpartnernetworkB_wt $controls b_mue_w if sur_round==3 & treat==0, 
	est sto spill

suest est3 spill CM_b, vce(robust)
	
nlcom [est3_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q mue_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef3="`b'`star'"
glo ase3="(\hspace{-0.1cm}`se')"


reg food_ins bpartnernetworkB_wt $controls b_food_ins if sur_round==3 & treat==0, 
	est sto spill

suest est4 spill CM_b, vce(robust)
	
nlcom [est4_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q food_ins, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef4="`b'`star'"
glo ase4="(\hspace{-0.1cm}`se')"


reg remittances_w bpartnernetworkB_wt $controls b_remittances_w if sur_round==3 & treat==0, 
	est sto spill

suest est5 spill CM_b, vce(robust)
	
nlcom [est5_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q remittances_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef5="`b'`star'"
glo ase5="(\hspace{-0.1cm}`se')"


reg IND_hh bpartnernetworkB_wt $controls b_IND_hh if sur_round==3 & treat==0, 
	est sto spill

suest est6 spill CM_b, vce(robust)
	
nlcom [est6_mean]treat + [spill_mean]bpartnernetworkB_wt*[CM_b_mean]_cons
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
		matselrc M adj_q, c(1) r(b pvalue)
		matname adj_q remittances_w, c(1) e
		matrix Adj_qval = Adj_qval , adj_q
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}	
			
glo acoef6="`b'`star'"
glo ase6="(\hspace{-0.1cm}`se')"

// Calculate Adjusted q-values
preserve
clear
matrix Adj_qval = Adj_qval'
svmat2 Adj_qval, names(col) rnames(Outcome)

rename pvalue pval
rename b coef

gen_qvals
matrix list Adj_qval

forval i=1/6 {
	local va`i':display %9.3f Adj_qval[`i',4] 
	di "`va`i''"
	global aqval`i' "[\hspace{-0.1cm}`va`i'']"
}
restore

// Control Means
summarize dexp_hh_w if (sur_round==3 & tmt=="C")
	global CM1  : disp %9.2f r(mean)
summarize dexp_w if (sur_round==3 & tmt=="C")
	global CM2  : disp %9.2f r(mean)
summarize mue_w if (sur_round==3 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize food_ins if (sur_round==3 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize remittances_w if (sur_round==3 & tmt=="C")
	global CM5  : disp %9.2f r(mean)
summarize IND_hh if (sur_round==3 & tmt=="C")
	global CM6  : disp %9.2f r(mean)

disp " Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5		& $acoef6 "
disp "			& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	& $ase6	 "
disp "			& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	& $aqval6	 "

********************************************************************************
// Endline
	
	tex \multicolumn{6}{c}{\textit{Panel B: Endline (18--24 Months)}} \\\\[-1ex]
	tex Adj. ITT	& $acoef1	 & $acoef2	 & $acoef3	 & $acoef4	 & $acoef5	& $acoef6	 \\
	tex				& $ase1		 & $ase2	 & $ase3	 & $ase4	 & $ase5	& $ase6	 \\
	tex				& $aqval1	 & $aqval2	 & $aqval3	 & $aqval4	 & $aqval5	& $aqval6	 \\
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5	& $n6		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5	& $CM6		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5	& $r6		 \\

********************************************************************************

* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{7}{@{} p{0.83\textwidth}}{\footnotesize{ \textit{Note:} We winsorize daily expenditures, MUE, and remittances at the 99th percentile. Coefficients are ANCOVA estimates that control for the outcome at baseline, the respondent's location, marital status, household size, number of children, age, network size and level of education. Adjusted ITT shows effects adjusted for positive spillovers to the control group. We calculate the MUE using consumption expenditures over the past week on seventeen food items, following the methods outlined in \textcite{Ligon:2020}. Higher values of the MUE indicate higher marginal utilities of expenditure, indicating that households are worse off. Food insecurity is a binary variable equal to one if the woman reports not having enough food more than once over the six months before the survey. Column (2) is included in column (1), however, we wanted to show the effect on the participating women expenditures as the information on the household corresponds to estimates the respondent thinks other members of the household have. Values in columns marked with heading \textit{Levels} are values in UGX. We report White robust standard errors in parentheses. Index is an Anderson index of all outcomes using the swindex command in Stata.  Multiple hypothesis test q-values (computed following Anderson (2008)) are presented in brackets. Q-values include the same controls as above and are computed within pre-registered families of outcomes.}}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................

est clear