/******************************************************************************* 
	Project: The Economics of Women Entrepreneurship
	Paper: Economic Inclusion through Entrepreneurship: Evidence on Building 
		   Skills for Women
	Title: Impact Evaluation SMS Lasso and Weights
	Authors: Megan Lang and Julia Seither
	RA: Maria Sofia Casabianca

	Description: This Do-file creates the tables in Appendix C. 
	
	STATA version: 18

	Date: Jan 05 - 2024 (creation date)										 
*******************************************************************************/

********************************************************************************
******************************* DATA PREPARATION *******************************
********************************************************************************
clear all
set more off
set varabbrev off

use "$path/../Data/IE_SMS_Lasso.dta", clear

********************************************************************************
************************* ORIGINAL COVARIATES GLOBALS ************************** 
********************************************************************************
global demographics "b_age b_sing b_mar b_div b_wid b_prim b_sec b_secPlus b_hh_size b_minors b_secgen_business b_p_prim b_p_sec b_m_prim b_m_sec b_employed b_location b_rent"
global insecurity "food_ins water_ins med_ins sch_ins"
global safety_inc "f9_a_d f9_b_d f9_c_d f9_d_d f9_e_d f9_f_d f9_g_d"
global networks "network networkB_wt familynetworkB_wt friendnetworkB_wt btalknetworkB_wt advicenetworkB_wt bpartnernetworkB_wt"
global busout_ext "b_b0 sales_last3_bin srp_bin ob_srp_bin"
global busout_int "bus_count sales_last3_w srp_w ob_srp_w"	
global mechoutI "b_track pric_mgt wk_hrs goal grit"
global mechoutII "s_eff loc_int loc_po loc_chance income_asp_w soc_stat_asp"
global hhout "dexp_hh_w dexp_w mue_w remittances_w"
global reinvout "savings_w ba_val_w ob_inv_w"
global covid "covid1 covid2"

********************************************************************************
*********************** NON-MISSINGS COVARIATES GLOBALS ************************
********************************************************************************
foreach var in $demographics $insecurity $safety_inc $networks $busout_ext $busout_int $mechoutI $mechoutII $hhout $reinvout $covid {
	gen `var'_nm = `var'
	gen flag_`var' = 0
		replace flag_`var' = 1 if `var'==.
	
	qui sum `var', d
	local median_age = r(p50)
	replace `var'_nm = `median_age' if flag_`var'==1
}
global demographics_nm "b_age_nm b_sing_nm b_mar_nm b_div_nm b_wid_nm b_prim_nm b_sec_nm b_secPlus_nm ib2.b_hh_size_nm ib2.b_minors_nm b_secgen_business_nm b_p_prim_nm b_p_sec_nm b_m_prim_nm b_m_sec_nm b_employed_nm i.b_location_nm b_rent_nm" // Non Parametric
global insecurity_nm "food_ins_nm water_ins_nm med_ins_nm sch_ins_nm"
global safety_inc_nm "f9_a_d_nm f9_b_d_nm f9_c_d_nm f9_d_d_nm f9_e_d_nm f9_f_d_nm f9_g_d_nm"
global networks_nm "network_nm networkB_wt_nm familynetworkB_wt_nm friendnetworkB_wt_nm btalknetworkB_wt_nm advicenetworkB_wt_nm bpartnernetworkB_wt_nm"
global busout_ext_nm "b_b0_nm sales_last3_bin_nm srp_bin_nm ob_srp_bin_nm"
global busout_int_nm "bus_count_nm sales_last3_w_nm srp_w_nm ob_srp_w_nm"	
global mechoutI_nm "b_track_nm pric_mgt_nm wk_hrs_nm goal_nm grit_nm"
global mechoutII_nm "s_eff_nm loc_int_nm loc_po_nm loc_chance_nm income_asp_w_nm soc_stat_asp_nm"
global hhout_nm "dexp_hh_w_nm dexp_w_nm mue_w_nm remittances_w_nm"
global reinvout_nm "savings_w_nm ba_val_w_nm ob_inv_w_nm"
global covid_nm "covid1_nm covid2_nm"

global imputed_dummies "flag_b_age flag_b_sing flag_b_mar flag_b_div flag_b_wid flag_b_prim flag_b_sec flag_b_secPlus flag_b_hh_size flag_b_minors flag_b_secgen_business flag_b_p_prim flag_b_p_sec flag_b_m_prim flag_b_m_sec flag_b_employed flag_b_location flag_b_rent flag_food_ins flag_water_ins flag_med_ins flag_sch_ins flag_f9_a_d flag_f9_b_d flag_f9_c_d flag_f9_d_d flag_f9_e_d flag_f9_f_d flag_f9_g_d flag_network flag_networkB_wt flag_familynetworkB_wt flag_friendnetworkB_wt flag_btalknetworkB_wt flag_advicenetworkB_wt flag_bpartnernetworkB_wt flag_b_b0 flag_sales_last3_bin flag_srp_bin flag_ob_srp_bin flag_bus_count flag_sales_last3_w flag_srp_w flag_ob_srp_w flag_b_track flag_pric_mgt flag_wk_hrs flag_goal flag_grit flag_s_eff flag_loc_int flag_loc_po flag_loc_chance flag_income_asp_w flag_soc_stat_asp flag_dexp_hh_w flag_dexp_w flag_mue_w flag_remittances_w flag_savings_w flag_ba_val_w flag_ob_inv_w flag_covid1 flag_covid2"


********************************************************************************
************************* NON-MISSING LASSO REGRESSION *************************
********************************************************************************
lab var b_smsansI "Baseline 0"

pdslasso b_smsansI treat ($demographics_nm $insecurity_nm $safety_inc_nm $networks_nm $busout_ext_nm $busout_int_nm $mechoutI_nm $mechoutII_nm $hhout_nm $reinvout_nm $covid_nm $imputed_dummies) , partial( $imputed_dummies) robust
gen spdslasso1 = e(sample) // Save the sample 
global 	selected_vars1 = e(xselected) // Keeping the selected variables in a global

eststo: reg b_smsansI $selected_vars1 // Estimate post-selection coefficients 
predict response 

lab var b_smsansI "Baseline Response"
lab var b_age_nm "Age"
lab var b_wid_nm "Widow"
lab var b_prim_nm "Primary Ed."
lab var b_sec_nm "Secondary Ed."
lab var b_hh_size_nm "HH Size"
lab var b_minors_nm "Minors in HH"
lab var b_secgen_business_nm "Parents had a Business"
lab var b_p_sec_nm "Father Secondary Edu."
lab var b_employed_nm "Employed"
lab var b_location_nm "Location"
lab var b_rent_nm "Pay Rent"
lab var sch_ins_nm "School Insecurity"
lab var f9_a_d_nm "Got business money stolen"
lab var f9_c_d_nm "Got personal money stolen"
lab var f9_e_d_nm "Robbed"
lab var networkB_wt_nm "Any Link to Treated"
lab var familynetworkB_wt_nm "Family Link to Treated"
lab var friendnetworkB_wt_nm "Friend Link to Treated"
lab var bpartnernetworkB_wt_nm "Business Link to Treated"
lab var sales_last3_bin_nm "$>0$ Sales"
lab var wk_hrs_nm "Work Hours"
lab var grit_nm "Grit"
lab var loc_int_nm "Locus of Control - Internal"
lab var loc_po_nm "Locus of Control - PO"
lab var soc_stat_asp_nm "Social Status Aspirations"

esttab est1 using "../Output/Tables/lassosms.tex", replace ///
prehead("\begin{table}[htbp]\tiny \centering \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \caption{Lasso Selected Variables - OLS \label{lassosms}} \\ \begin{tabular}{l*{1}{c}} \toprule \toprule") ///
fragment ///
b(3) se(3) nostar ////
label scalars( "N Obs." "r2_a Adj. R$^2$") sfmt(3) ///
prefoot("\bottomrule") ///
postfoot("\bottomrule \bottomrule \multicolumn{2}{@{} p{0.6\textwidth}}{\footnotesize{\textit{Note:} }} \end{tabular} \\ \end{table}")

est clear


********************************************************************************
************************* CALCULATE PHOTOBOOK WEIGHTS **************************
********************************************************************************
use "$path/../Data/Full_withNetworks_annon.dta", clear

********************
//* Prep Dataset
********************
sort id sur_round
xtset id sur_round

// Cleaning Photobook Variable (h0)
tab h0, m 
replace h0 = . if h0 == 99 | h0 == 16 | h0 == .a | h0 == 20149  | h0 == 30153 | h0 == 50153 | h0 == 50215

keep id sur_round h0 nwlink*
drop if sur_round == .

rename nwlink* nwlink_*

reshape long nwlink_, i(id sur_round h0) j(j)
drop j 
drop if nwlink_ == .

// Count time a participant is identified by Photobook and sur_round
egen dups = count(id), by(sur_round nwlink_ h0)

drop id
duplicates drop
rename nwlink_ id
 
tempfile identified
save `identified'

********************
//* Photobook Order
********************
use "$path/../Data/Photobook_order_annon.dta", clear

rename PB*_page PB_page*
rename PB*_pagePos PB_pagePos*

reshape long PB PB_page PB_pagePos, i(id) j(h0)

drop if PB == .
tempfile PB
save `PB'

use `identified', clear
merge m:1 id h0 using `PB'

// Dummies for PB_page
tabulate PB_page, gen(page)

// Dummies for PB_pagePos
tabulate PB_pagePos, gen(pagePos)

drop _merge
save "$path/../Data/PB_order.dta", replace

global page "page2 page3 page4 page5 page6 page7 page8 page9 page10 page11 page12 page13 page14 page15 page16"
global pagePos "pagePos2 pagePos3 pagePos4 pagePos5 pagePos6 pagePos7 pagePos8 pagePos9 pagePos10 pagePos11 pagePos12 pagePos13 pagePos14 pagePos15 pagePos16"

forvalues i = 1(1)16{
	lab var page`i' "`i'"
	lab var pagePos`i' "`i'"
}
label var dups " "
label define survey 1 "Baseline" 2 "Midline" 3 "Endline"
label values sur_round survey

// Chosen Regs
areg dups PB_page PB_pagePos i.sur_round , a(id) robust
areg dups $page $pagePos i.sur_round, a(id) robust
matrix M = r(table)
matselrc M Data_table,  c(1/30) r(b se pvalue)
matselrc M M, c(1/30) r(b)
matrix M = M'

matewmf M M, f(abs)

matrix coef = J(15,2,.)
matname coef page pagePos, c(1..2) e

forvalues i=1(1)15{
	matrix coef[`i',1] = M[`i',1]
}

local j = 1

forvalues i=16(1)30{
	matrix coef[`j',2] = M[`i',1]
	local j = `j' +1
}

matrix page1 =J(1,2,.)
	matrix page1[1,1] = 0
	matrix page1[1,2] = 0

matrix coef = page1 \ coef

matrix weight=J(256,3,.)
matname weight PB_page PB_pagePos weight, c(1..3) e

local k = 1

forvalues i = 1(1)16{ //Pages
	forvalues j = 1(1)16{ //Page Position
		matrix weight[`k',1] = `i'
		matrix weight[`k',2] = `j'
		matrix weight[`k',3] = 1 + coef[`i',1] + coef[`j',2]
		
		local k = `k'+1
	}
}

/*******************************************************************************
							COEFFICIENTS TABLE
*******************************************************************************/
matrix list Data_table
matrix Data_table = Data_table'

// Loop Coefficients 
forvalues i = 1(1)30{
	local b		: disp %9.3f Data_table[`i',1]
	local se	: disp %9.3f Data_table[`i',2]
	local pval	: disp %4.3f Data_table[`i',3]
	
	local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
	
	glo coef`i'="`b'"
	glo se`i'="(\hspace{-0.1cm}`se')"
	
}

* Start head ...................................................................
	cap texdoc close
	texdoc init "$path/../Output/Tables/pbcoefs.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize
	tex \caption{Estimated Coefficients for Photo books Weights \label{pbcoef}}
	tex \begin{tabular}{l*{2}{c}}			
	tex \toprule \toprule
	tex 	&	\multicolumn{1}{c}{(1)}		&	\multicolumn{1}{c}{(2)}				\\
	tex 	&	\multicolumn{1}{c}{Page}	&	\multicolumn{1}{c}{Page Position}	\\ \midrule
	tex 1	&	0.000 						&	0.000								\\
	tex		&	(.)							&	(.)									\\

* End head .....................................................................
	tex	2	&	$coef1					 &	$coef16								 \\
	tex		&	$se1					 &	$se16								 \\
	tex	3	&	$coef2					 &	$coef17								 \\
	tex		&	$se2					 &	$se17								 \\
	tex	4	&	$coef3					 &	$coef18								 \\
	tex		&	$se3					 &	$se18								 \\
	tex	5	&	$coef4					 &	$coef19								 \\
	tex		&	$se4					 &	$se19								 \\
	tex	6	&	$coef5					 &	$coef20								 \\
	tex		&	$se5					 &	$se20								 \\
	tex	7	&	$coef6					 &	$coef21								 \\
	tex		&	$se6					 &	$se21								 \\
	tex	8	&	$coef7					 &	$coef22								 \\
	tex		&	$se7					 &	$se22								 \\
	tex	9	&	$coef8					 &	$coef23								 \\
	tex		&	$se8					 &	$se23								 \\
	tex	10	&	$coef9					 &	$coef24								 \\
	tex		&	$se9					 &	$se24								 \\
	tex	11	&	$coef10					 &	$coef25								 \\
	tex		&	$se10					 &	$se25								 \\
	tex	12	&	$coef11					 &	$coef26								 \\
	tex		&	$se11					 &	$se26								 \\
	tex	13	&	$coef12					 &	$coef27								 \\
	tex		&	$se12					 &	$se27								 \\
	tex	14	&	$coef13					 &	$coef28								 \\
	tex		&	$se13					 &	$se28								 \\
	tex	15	&	$coef14					 &	$coef29								 \\
	tex		&	$se14					 &	$se29								 \\
	tex	16	&	$coef15					 &	$coef30								 \\
	tex		&	$se15					 &	$se30								 \\	
* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{3}{@{} p{0.3\textwidth}}{\footnotesize{\textit{Note:} }}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................	