/******************************************************************************* 
	Project: The Economics of Women Entrepreneurship
	Paper: Economic Inclusion through Entrepreneurship: Evidence on Building 
		   Skills for Women
	Title: Impact Evaluation SMS Lasso and Weights
	Authors: Megan Lang and Julia Seither
	RA: Maria Sofia Casabianca

	Description: This Do-file creates the tables in Appendix D. 
	
	STATA version: 18

	Date: Jan 05 - 2024 (creation date)										 
*******************************************************************************/
********************************************************************************
******************************* DATA PREPARATION *******************************
********************************************************************************
clear all
set more off
set varabbrev off


cd "$path/../Data"
use "IE_Submission.dta", clear

sort id sur_round
xtset id sur_round

/*
* Install ftools (remove program if it existed previously)
cap ado uninstall ftools
net install ftools, from("https://raw.githubusercontent.com/sergiocorreia/ftools/master/src/")

* Install reghdfe
cap ado uninstall reghdfe
net install reghdfe, from("https://raw.githubusercontent.com/sergiocorreia/reghdfe/master/src/")

* Install ivreg2, the core package
cap ado uninstall ivreg2
ssc install ivreg2

* Finally, install this package
cap ado uninstall ivreghdfe
net install ivreghdfe, from(https://raw.githubusercontent.com/sergiocorreia/ivreghdfe/master/src/)
*/

********************************************************************************
***************************** BASELINE STATISTICS ******************************
********************************************************************************
tab tmt sur_round,m 

tab tmt location if sur_round==1, m 

********************************************************************************
************************ CONTROL GLOBALS AND COVARIATES ************************
********************************************************************************
global controls = "i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age"

global controlsBalance = "b_age	b_mar	b_div	b_sing	b_prim	b_sec	b_p_prim	b_p_sec	b_m_prim	b_m_sec	b_employed	b_hh_size	b_minors	b_dexp_hh_w	b_savings_w	b_remittances_w	b_b0	b_sales_last3_w	b_srp_w	b_ob_srp_w	b_network	b_loc_int	b_loc_po	b_loc_chance"

/*******************************************************************************
				CALCULATING TREATMENT EFFECTS ON BUSINESS OUTCOMES
					ROBUSTNESS CHECKS - OTHER SPECIFICATIONS

Table A12: Treatment Effects on Business Outcomes Extensive Margin - Other Specifications
File name: busoutrobust1.tex
*******************************************************************************/
global busout1 "b0 bus_count sales_last3_bin srp_bin ob_srp_bin tot_srp_bin"

lab var b0 "Own a Business"
lab var bus_count "No. Businesses"
lab var sales_last3_bin "$>0$ Sales" 
lab var srp_bin "$>0$ Profits - MB"
lab var ob_srp_bin "$>0$ Profits - OB"
lab var tot_srp_bin "$>0$ Profits - All Businesses"
******************************* Table File Code ********************************
local h = 1
	
foreach i in $busout1{

	local varlabel : var label `i'
	// 		Midline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==2, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==2, robust	
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==2), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==2, absorb(b_age) robust 
		
	//		Endline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==3, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==3, robust
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==3), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==3, absorb(b_age) robust 
	
		if `h' == 1 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/busoutrobust1.tex", replace nomtitles rename(realtreat treat) ///
			prehead("\begin{table}[htbp]\footnotesize \centering \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \caption{Treatment Effects on Business Outcomes Extensive Margin - Other Specifications \label{busout:robust1}} \\ \begin{tabular}{l*{8}{c}} \toprule \toprule") ///
			posthead("\midrule  \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.") sfmt(3) ///
			 mgroups("Midline (6 months)" "Endline (18--24 Months)", pattern(1 0 0 0 1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
			prefoot("\midrule")
			
			local h = `h' + 1
		}
		else if `h'> 1 & `h'< 6 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/busoutrobust1.tex", append nomtitles nonumbers rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) ///
			prefoot("\midrule")

			local h = `h' + 1			
		}			
		else {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/busoutrobust1.tex", append rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ////
			fragment ////
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) nomtitles nonumbers ///
			prefoot("\bottomrule") ///
			postfoot("\bottomrule \\[-1ex] Controls & & \checkmark & & \checkmark & & \checkmark & & \checkmark \\ FE & & & \checkmark & & & & \checkmark & \\ \bottomrule \bottomrule  \multicolumn{9}{@{} p{0.95\textwidth}}{\footnotesize{ \textit{Note:} Columns (1), (2), (5) and (6) present the results of the OLS specification, columns (3) and (7) present the results of the two-way fixed effects specification, and columns (4) and (8) present results from the ANCOVA IV specification where we instrument for actual treatment with assigned treatment to account for imperfect compliance. Coefficients in columns (2), (4), (6), and (8) control for the respondent's location, marital status, household size, number of children, age, network size and level of education. We report standard errors clustered at the individual level in parentheses in columns (3) and (7) and White robust standard errors in all other columns.}} \end{tabular} \\ \end{table}")
		
			local h = `h' + 1
		}
	
	est clear 	
}

/*******************************************************************************
				CALCULATING TREATMENT EFFECTS ON BUSINESS OUTCOMES
					ROBUSTNESS CHECKS - OTHER SPECIFICATIONS

Table A13: Treatment Effects on Business Outcomes intensive Margin - Other Specifications
File name: busoutrobust2.tex
*******************************************************************************/
global busout2 "sales_last3_w srp_w ob_srp_w tot_srp_w"

lab var sales_last3_w "Sales (Levels)"
lab var srp_w "Profits (Levels) - MB"
lab var ob_srp_w "Profits (Levels) - OB"
lab var tot_srp_w "Profits (Levels) - All Businesses"

******************************* Table File Code ********************************
local h = 1
	
foreach i in $busout2{

	local varlabel : var label `i'
	// 		Midline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==2, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==2, robust	
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==2), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==2, absorb(b_age) robust 
		
	//		Endline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==3, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==3, robust
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==3), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==3, absorb(b_age) robust 
	
		if `h' == 1 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/busoutrobust2.tex", replace nomtitles rename(realtreat treat) ///
			prehead("\begin{table}[htbp]\footnotesize \centering \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \caption{Treatment Effects on Business Outcomes Intensive Margin - Other Specifications \label{busout:robust2}} \\ \begin{tabular}{l*{8}{c}} \toprule \toprule") ///
			posthead("\midrule  \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.") sfmt(3) ///
			 mgroups("Midline (6 months)" "Endline (18--24 Months)", pattern(1 0 0 0 1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
			prefoot("\midrule")
			
			local h = `h' + 1
		}
		else if `h'> 1 & `h'< 4 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/busoutrobust2.tex", append nomtitles nonumbers rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) ///
			prefoot("\midrule")

			local h = `h' + 1			
		}			
		else {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/busoutrobust2.tex", append rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ////
			fragment ////
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) nomtitles nonumbers ///
			prefoot("\bottomrule") ///
			postfoot("\bottomrule \\[-1ex] Controls & & \checkmark & & \checkmark & & \checkmark & & \checkmark \\ FE & & & \checkmark & & & & \checkmark & \\ \bottomrule \bottomrule  \multicolumn{9}{@{} p{1.2\textwidth}}{\footnotesize{ \textit{Note:} Columns (1), (2), (5) and (6) present the results of the OLS specification, columns (3) and (7) present the results of the two-way fixed effects specification, and columns (4) and (8) present results from the ANCOVA IV specification where we instrument for actual treatment with assigned treatment to account for imperfect compliance. We winsorize all sales and profit measures at the 99th percentile. Coefficients in columns (2), (4), (6), and (8) control for the respondent's location, marital status, household size, number of children, age, network size and level of education. Values in rows marked with heading \textit{Levels} are values in UGX. We report standard errors clustered at the individual level in parentheses in columns (3) and (7) and White robust standard errors in all other columns.}} \end{tabular} \\ \end{table}")
		
			local h = `h' + 1
		}
	
	est clear 	
}

/*******************************************************************************
				CALCULATING TREATMENT EFFECTS ON POSSIBLE MECHANISMS
					ROBUSTNESS CHECKS - OTHER SPECIFICATIONS

Table A14: Treatment Effects on Possible Mechanisms I - Other Specifications
File name: mechoutrobust1.tex
*******************************************************************************/
global mech1 = "b_track pric_mgt wk_hrs goal grit s_eff"

lab var b_track "Tracking"
lab var pric_mgt "Price Mgmt."
lab var goal "Goal Setting"
lab var wk_hrs "Work Hours"
lab var grit "Grit"
lab var s_eff "Self-Efficacy"
******************************* Table File Code ********************************
local h = 1

foreach i in $mech1{

	local varlabel : var label `i'
	// 		Midline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==2, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==2, robust	
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==2), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==2, absorb(b_age) robust 
		
	//		Endline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==3, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==3, robust
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==3), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==3, absorb(b_age) robust

	
		if `h' == 1 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/mechoutrobust1.tex", replace nomtitles rename(realtreat treat) ///
			prehead("\begin{table}[htbp]\footnotesize \centering \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \caption{Treatment Effects on Possible Mechanisms I - Other Specifications \label{mechout:robust1}} \\ \begin{tabular}{l*{8}{c}} \toprule \toprule") ///
			posthead("\midrule  \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.") sfmt(3) ///
			 mgroups("Midline (6 months)" "Endline (18--24 Months)", pattern(1 0 0 0 1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
			prefoot("\midrule")
			
			local h = `h' + 1
		}
		else if `h'> 1 & `h'< 6 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/mechoutrobust1.tex", append nomtitles nonumbers rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) ///
			prefoot("\midrule")

			local h = `h' + 1			
		}			
		else {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/mechoutrobust1.tex", append rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ////
			fragment ////
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) nomtitles nonumbers ///
			prefoot("\bottomrule") ///
			postfoot("\bottomrule \\[-1ex] Controls & & \checkmark & & \checkmark & & \checkmark & & \checkmark \\ FE & & & \checkmark & & & & \checkmark & \\ \bottomrule \bottomrule  \multicolumn{9}{@{} p{0.99\textwidth}}{\footnotesize{ \textit{Note:} Columns (1), (2), (5) and (6) present the results of the OLS specification, columns (3) and (7) present the results of the two-way fixed effects specification, and columns (4) and (8) present results from the ANCOVA IV specification where we instrument for actual treatment with assigned treatment to account for imperfect compliance. Coefficients in columns (2), (4), (6), and (8) control for the respondent's location, marital status, household size, number of children, age, network size and level of education. We report standard errors clustered at the individual level in parentheses in columns (3) and (7) and White robust standard errors in all other columns.}} \end{tabular} \\ \end{table}")
		
			local h = `h' + 1
		}
	
	est clear 	
}

/*******************************************************************************
				CALCULATING TREATMENT EFFECTS ON POSSIBLE MECHANISMS
					ROBUSTNESS CHECKS - OTHER SPECIFICATIONS

Table A15: Treatment Effects on Possible Mechanisms II - Other Specifications
File name: mechoutrobust2.tex
*******************************************************************************/
global mech2 = "loc_int loc_po loc_chance income_asp_w soc_stat_asp"

lab var loc_int "Locus of Control - Internal"
lab var loc_po "Locus of Control - PO"
lab var loc_chance "Locus of Control - Chance" 
lab var income_asp_w "Aspirations - Income (Levels)" 
lab var soc_stat_asp "Aspirations - Social Status"

******************************* Table File Code ********************************
local h = 1
	
foreach i in $mech2{

	local varlabel : var label `i'
	// 		Midline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==2, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==2, robust	
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==2), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==2, absorb(b_age) robust 
		
	//		Endline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==3, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==3, robust
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==3), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==3, absorb(b_age) robust

	
		if `h' == 1 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/mechoutrobust2.tex", replace nomtitles rename(realtreat treat) ///
			prehead("\begin{table}[htbp]\footnotesize \centering \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \caption{Treatment Effects on Possible Mechanisms II - Other Specifications \label{mechout:robust2}} \\ \begin{tabular}{l*{8}{c}} \toprule \toprule") ///
			posthead("\midrule  \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.") sfmt(3) ///
			 mgroups("Midline (6 months)" "Endline (18--24 Months)", pattern(1 0 0 0 1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
			prefoot("\midrule")
			
			local h = `h' + 1
		}
		else if `h'> 1 & `h'< 5 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/mechoutrobust2.tex", append nomtitles nonumbers rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) ///
			prefoot("\midrule")

			local h = `h' + 1			
		}			
		else {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/mechoutrobust2.tex", append rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ////
			fragment ////
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) nomtitles nonumbers ///
			prefoot("\bottomrule") ///
			postfoot("\bottomrule \\[-1ex] Controls & & \checkmark & & \checkmark & & \checkmark & & \checkmark \\ FE & & & \checkmark & & & & \checkmark & \\ \bottomrule \bottomrule  \multicolumn{9}{@{} p{1.3\textwidth}}{\footnotesize{ \textit{Note:} Columns (1), (2), (5) and (6) present the results of the OLS specification, columns (3) and (7) present the results of the two-way fixed effects specification, and columns (4) and (8) present results from the ANCOVA IV specification where we instrument for actual treatment with assigned treatment to account for imperfect compliance. We winsorize all income aspirations measures at the 99th percentile. Coefficients in columns (2), (4), (6), and (8) control for the respondent's location, marital status, household size, number of children, age, network size and level of education. Values in rows marked with heading \textit{Levels} are values in UGX. We report standard errors clustered at the individual level in parentheses in columns (3) and (7) and White robust standard errors in all other columns.}} \end{tabular} \\ \end{table}")
		
			local h = `h' + 1
		}
	
	est clear 	
}

/*******************************************************************************
			CALCULATING TREATMENT EFFECTS ON RE-INVESTMENTS OUTCOMES
					ROBUSTNESS CHECKS - OTHER SPECIFICATIONS

Table A16: Treatment Effects on Re-Investments - Other Specifications
File name: reinvoutrobust.tex
*******************************************************************************/
global reinvout = "savings_w ba_val_w ob_inv_w"

lab var savings_w "Savings (Levels)"
lab var ba_val_w "Business Assets (Levels)"
lab var ob_inv_w "Investments in Other Businesses (Levels)"

******************************* Table File Code ********************************
local h = 1
	
foreach i in $reinvout{

	local varlabel : var label `i'
	// 		Midline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==2, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==2, robust
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==2), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==2, absorb(b_age) robust 
		
	//		Endline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==3, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==3, robust
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==3), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==3, absorb(b_age) robust

	
		if `h' == 1 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/reinvoutrobust.tex", replace nomtitles rename(realtreat treat) ///
			prehead("\begin{table}[htbp]\footnotesize \centering \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \caption{Treatment Effects on Re-Investments - Other Specifications \label{reinvoutrobust}} \\ \begin{tabular}{l*{8}{c}} \toprule \toprule") ///
			posthead("\midrule  \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.") sfmt(3) ///
			 mgroups("Midline (6 months)" "Endline (18--24 Months)", pattern(1 0 0 0 1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
			prefoot("\midrule")
			
			local h = `h' + 1
		}
		else if `h'> 1 & `h'< 3 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/reinvoutrobust.tex", append nomtitles nonumbers rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) ///
			prefoot("\midrule")

			local h = `h' + 1			
		}			
		else {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/reinvoutrobust.tex", append rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ////
			fragment ////
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) nomtitles nonumbers ///
			prefoot("\bottomrule") ///
			postfoot("\bottomrule \\[-1ex] Controls & & \checkmark & & \checkmark & & \checkmark & & \checkmark \\ FE & & & \checkmark & & & & \checkmark & \\ \bottomrule \bottomrule  \multicolumn{9}{@{} p{1.22\textwidth}}{\footnotesize{ \textit{Note:} Columns (1), (2), (5) and (6) present the results of the OLS specification, columns (3) and (7) present the results of the two-way fixed effects specification, and columns (4) and (8) present results from the ANCOVA IV specification where we instrument for actual treatment with assigned treatment to account for imperfect compliance. We winsorize savings, business assets and investments measures at the 99th percentile. Coefficients in columns (2), (4), (6), and (8) control for the respondent's location, marital status, household size, number of children, age, network size and level of education. Values in rows marked with heading \textit{Levels} are values in UGX. We report standard errors clustered at the individual level in parentheses in columns (3) and (7) and White robust standard errors in all other columns.}} \end{tabular} \\ \end{table}")
		
			local h = `h' + 1
		}
	
	est clear 	
}

/*******************************************************************************
			  CALCULATING TREATMENT EFFECTS ON HOUSEHOLD OUTCOMES
					ROBUSTNESS CHECKS - OTHER SPECIFICATIONS

Table A17: Treatment Effects on Household Outcomes I - Other Specifications
File name: hhoutrobust1.tex
*******************************************************************************/
global hhout1 = "dexp_hh_w dexp_w mue_w food_ins remittances_w "

lab var dexp_hh_w "Daily HH Expenditure (Levels)"
lab var dexp_w "Participant Expenditure (Levels)"
lab var mue_w "MUE"
lab var food_ins "Food Insecurity"
lab var remittances_w "Remittances (Levels)"

******************************* Table File Code ********************************
local h = 1
	
foreach i in $hhout1 {

	local varlabel : var label `i'
	// 		Midline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==2, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==2, robust
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==2), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==2, absorb(b_age) robust
		
	//		Endline
	*OLS as if we had no baseline
	eststo, e: reg `i' treat if sur_round==3, robust
		
	*OLS controlling for certain baseline covariates
	eststo, e: reg `i' treat $controls if sur_round==3, robust		
		
	*Twoway fixed effects	
	eststo, e: reghdfe `i' treat if (sur_round==1|sur_round==3), absorb(id sur_round) vce(cluster id)
		
	*IV accounting for imperfect compliance with treatment
	eststo, e: ivreghdfe `i' b_`i' $controls (realtreat = treat) if sur_round==3, absorb(b_age) robust
	
		if `h' == 1 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/hhoutrobust1.tex", replace nomtitles rename(realtreat treat) ///
			prehead("\begin{table}[htbp]\footnotesize \centering \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \caption{Treatment Effects on Household Outcomes - Other Specifications \label{hhout:robust1}} \\ \begin{tabular}{l*{8}{c}} \toprule \toprule") ///
			posthead("\midrule  \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.") sfmt(3) ///
			 mgroups("Midline (6 months)" "Endline (18--24 Months)", pattern(1 0 0 0 1 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
			prefoot("\midrule")
			
			local h = `h' + 1
		}
		else if `h'> 1 & `h'< 5 {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/hhoutrobust1.tex", append nomtitles nonumbers rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ///
			fragment ///
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) ///
			prefoot("\midrule")

			local h = `h' + 1			
		}			
		else {
			esttab est1 est2 est3 est4 est5 est6 est7 est8 using "$path/../Output/Tables/hhoutrobust1.tex", append rename(realtreat treat) ///
			posthead("\midrule \multicolumn{9}{l}{\textbf{`varlabel'}} \\\\[-1ex]") ////
			fragment ////
			b(3) se(3) nostar ////
			keep(treat) coeflabel(treat "Treat") ///
			label scalars("N Obs.")	sfmt(3) nomtitles nonumbers ///
			prefoot("\bottomrule") ///
			postfoot("\bottomrule \\[-1ex] Controls & & \checkmark & & \checkmark & & \checkmark & & \checkmark \\ FE & & & \checkmark & & & & \checkmark & \\ \bottomrule \bottomrule  \multicolumn{9}{@{} p{1.17\textwidth}}{\footnotesize{ \textit{Note:} Columns (1), (2), (5) and (6) present the results of the OLS specification, columns (3) and (7) present the results of the two-way fixed effects specification, and columns (4) and (8) present results from the ANCOVA IV specification where we instrument for actual treatment with assigned treatment to account for imperfect compliance. We winsorize daily expenditure measures and remittances at the 99th percentile. Coefficients in columns (2), (4), (6), and (8) control for the respondent's location, marital status, household size, number of children, age, network size and level of education. Values in rows marked with heading \textit{Levels} are values in UGX. We report standard errors clustered at the individual level in parentheses in columns (3) and (7) and White robust standard errors in all other columns.}} \end{tabular} \\ \end{table}")
		
			local h = `h' + 1
		}
	
	est clear 	
}
