/******************************************************************************* 
	Paper: Economic Inclusion through Entrepreneurship: Evidence on Building 
		   Skills for Women
	Title: Impact Evaluation Analysis and Tables Creation
	Authors: Megan Lang and Julia Seither
	RA: Maria Sofia Casabianca

	Description: This Do-file presents the analysis in which the paper is based.
				 It creates all the tables in the main paper.
	
	STATA version: 18

	Date: Oct 25 - 2024 (Last Update)										 
*******************************************************************************/

********************************************************************************
******************************* DATA PREPARATION *******************************
********************************************************************************
clear all
set more off
set varabbrev off

use "$path/../Data/IE_Submission.dta", clear

sort id sur_round
xtset id sur_round

*ssc install texdoc, replace
*ssc install rwolf, replace

********************************************************************************
*********************** PROGRAM DEFINITION FOR Q-VALUES ************************
********************************************************************************
/*NOTE:
This is taken directly from Michael Anderson's Stata code, which "generates BKY 
(2006) sharpened two-stage q-values as described in Anderson (2008), "Multiple 
Inference and Gender Differences in the Effects of Early Intervention: A Reeva-
luation of the Abecedarian, Perry Preschool, and Early Training Projects", Jour-
nal of the American Statistical Association, 103(484), 1481-1495.

The original code is found in: https://are.berkeley.edu/~mlanderson/ARE_Website/Research.html
*/
program define gen_qvals, rclass
	version 18.0
	
// Collect the total number of p-values tested
	quietly sum pval
	local totalpvals = r(N)
// Sort the p-values in ascending order and generate a variable that codes each p-value's rank
	quietly gen int original_sorting_order = _n
	quietly sort pval
	quietly gen int rank = _n if pval != .
	
// Set the initial counter to 1 
	local qval = 1
	
// Generate the variable that will contain the BKY (2006) sharpened q-values
	gen bky06_qval = 1 if pval != .

// Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.
while `qval' > 0 {
	// First Stage
	// Generate the adjusted first stage q level we are testing: q' = q/1+q
	local qval_adj = `qval' / ( 1 + `qval' )
	// Generate value q'//r/M
	gen fdr_temp1 = `qval_adj' * rank / `totalpvals'
	// Generate binary variable checking condition p(r) <= q'*r/M
	gen reject_temp1 = ( fdr_temp1 >= pval ) if pval != .
	// Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank1 = reject_temp1 * rank
	// Record the rank of the largest p-value that meets above condition
	egen total_rejected1 = max( reject_rank1 )

	// Second Stage
	// Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
	local qval_2st = `qval_adj' * ( `totalpvals' / ( `totalpvals' - total_rejected1[1] ) )
	// Generate value q_2st*r/M
	gen fdr_temp2 = `qval_2st' * rank / `totalpvals'
	// Generate binary variable checking condition p(r) <= q_2st*r/M
	gen reject_temp2 = ( fdr_temp2 >= pval ) if pval != .
	// Generate variable containing p-value ranks for all p-values that meet above condition
	gen reject_rank2 = reject_temp2 * rank
	// Record the rank of the largest p-value that meets above condition
	egen total_rejected2 = max( reject_rank2 )

	// A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
	replace bky06_qval = `qval' if rank <= total_rejected2 & rank != .
	// Reduce q by 0.001 and repeat loop
	drop fdr_temp* reject_temp* reject_rank* total_rejected*
	local qval = `qval' - .001
}
	
	quietly sort original_sorting_order
	
	list Outcome coef pval bky06_qval original_sorting_order 
	
	mkmat original_sorting_order coef pval bky06_qval, matrix(Adj_qval)
	
end

********************************************************************************
***************************** BASELINE STATISTICS ******************************
********************************************************************************
tab tmt sur_round,m 

tab tmt location if sur_round==1, m 

********************************************************************************
************************ CONTROL GLOBALS AND COVARIATES ************************
********************************************************************************
global controls = "i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age"

global controlsBalance = "b_age	b_mar	b_div	b_sing	b_prim	b_sec	b_p_prim	b_p_sec	b_m_prim	b_m_sec	b_employed	b_hh_size	b_minors	b_dexp_hh_w	b_savings_w	b_remittances_w	b_b0	b_sales_last3_w	b_srp_w	b_ob_srp_w	b_network	b_loc_int	b_loc_po	b_loc_chance"

********************************************************************************
************************ MAIN REGRESSIONS AND ANALYSIS *************************
********************************************************************************
cd "$path/../Output/Tables"

/*******************************************************************************
	 TREATMENT EFFECTS ON SKILLS
	   
	Table 1. 
	File name: mechout_itt.tex
*******************************************************************************/
lab var b_track "Tracking"
lab var pric_mgt "Price Mgmt."
lab var wk_hrs "Work Hours"
lab var goal "Goal Setting"
lab var grit "Grit"
lab var loc_int "Internal"
lab var loc_po "PO"
lab var loc_chance "Chance" 
lab var income_asp_w "Levels" 
lab var IND_skills "Skills Index"

******************************* Table File Code ********************************
* Start head ...................................................................
	cap texdoc close
	texdoc init "mechout_itt.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize		
	tex \caption{ITT Effects: Skills \label{mechout:itt}}
	tex \begin{tabular}{l*{10}{c}}			
	tex \toprule \toprule	
	tex &	\multicolumn{4}{c}{ }	&	\multicolumn{1}{c}{ }&\multicolumn{3}{c}{Locus of Control}	&	\multicolumn{1}{c}{Income Aspirations} &	\multicolumn{1}{c}{ }    \\\cmidrule(lr){7-9}\cmidrule(lr){10-10}
	tex &	\multicolumn{1}{c}{(1)}	&	\multicolumn{1}{c}{(2)}	&	\multicolumn{1}{c}{(3)}	&	\multicolumn{1}{c}{(4)}	&	\multicolumn{1}{c}{(5)}	&	\multicolumn{1}{c}{(6)}	&	\multicolumn{1}{c}{(7)}	&	\multicolumn{1}{c}{(8)}	&	\multicolumn{1}{c}{(9)} & \multicolumn{1}{c}{(10)}\\
	tex &	\multicolumn{1}{c}{Tracking}	&	\multicolumn{1}{c}{Price Mgmt.}	&	\multicolumn{1}{c}{Work Hours}	&	\multicolumn{1}{c}{Goal Setting}	&	\multicolumn{1}{c}{Grit}	&	\multicolumn{1}{c}{Internal}	&	\multicolumn{1}{c}{PO}	&	\multicolumn{1}{c}{Chance}	&	\multicolumn{1}{c}{Levels} & \multicolumn{1}{c}{Index}\\ \midrule \\

* End head .....................................................................

rwolf b_track pric_mgt wk_hrs goal grit loc_int loc_po loc_chance income_asp_w IND_skills if sur_round==2, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/10 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg b_track treat b_b_track $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg pric_mgt treat b_pric_mgt $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg wk_hrs treat b_wk_hrs $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg goal treat b_goal $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg grit treat b_grit $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	


reg loc_int treat b_loc_int $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"

reg loc_po treat b_loc_po $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n7 = "`obs'"
	global r7 = "`r2'"
est sto est7
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef7="`b'`star'"
glo se7="(\hspace{-0.1cm}`se')"
	

reg loc_chance treat b_loc_chance $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n8 = "`obs'"
	global r8 = "`r2'"
est sto est8
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef8="`b'`star'"
glo se8="(\hspace{-0.1cm}`se')"
	
	
reg income_asp_w treat b_income_asp_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n9 = "`obs'"
	global r9 = "`r2'"
est sto est9
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef9="`b'`star'"
glo se9="(\hspace{-0.1cm}`se')"	

reg IND_skills treat b_IND_skills $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n10 = "`obs'"
	global r10 = "`r2'"
est sto est10
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef10="`b'`star'"
glo se10="(\hspace{-0.1cm}`se')"	

// Control Means
summarize b_track if (sur_round==2 & tmt=="C")
	global CM1  : disp %9.3f r(mean)
summarize pric_mgt if (sur_round==2 & tmt=="C")
	global CM2  : disp %9.3f r(mean)
summarize wk_hrs if (sur_round==2 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize goal if (sur_round==2 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize grit if (sur_round==2 & tmt=="C")
	global CM5  : disp %9.3f r(mean)
summarize loc_int if (sur_round==2 & tmt=="C")
	global CM6  : disp %9.3f r(mean)
summarize loc_po if (sur_round==2 & tmt=="C")
	global CM7  : disp %9.3f r(mean)
summarize loc_chance if (sur_round==2 & tmt=="C")
	global CM8  : disp %9.3f r(mean)
summarize income_asp_w if (sur_round==2 & tmt=="C")
	global CM9  : disp %12.2f r(mean)
summarize IND_skills if (sur_round==2 & tmt=="C")
	global CM10  : disp %12.2f r(mean)

disp "ITT   &  $coef1    &  $coef2   &  $coef3   & $coef4    & $coef5	& $coef6	&  $coef7   & $coef8    & $coef9	& $coef10	"
disp "		& $se1		 & $se2		 & $se3		 & $se4		 & $se5		& $se6	&  $se7   & $se8    & $se9	& $se10	"
disp "		& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	& $qval6	&  $qval7   & $qval8    & $qval9	& $qval10	"

********************************************************************************
// Midline
	
	tex \multicolumn{11}{c}{\textit{Panel A: Midline (6 months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	 & $coef4	 & $coef5	 & $coef6	 &  $coef7   & $coef8    & $coef9	& $coef10	 \\
	tex				& $se1		 & $se2		 & $se3		 & $se4		 & $se5		 & $se6	 	 &  $se7	 & $se8		 & $se9		& $se10		 \\
	tex				& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	 & $qval6	 &  $qval7   & $qval8    & $qval9 	& $qval10	 \\
	tex \addlinespace[5pt]	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5		 & $n6	 & $n7		 & $n8		 & $n9	& $n10			 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5		 & $CM6	 & $CM7		 & $CM8		 & $CM9	& $CM10			 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5		 & $r6	 & $r7		 & $r8		 & $r9	& $r10			 \\
	tex \midrule \\

********************************************************************************

rwolf b_track pric_mgt wk_hrs goal grit loc_int loc_po loc_chance income_asp_w IND_skills if sur_round==3, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/10 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg b_track treat b_b_track $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg pric_mgt treat b_pric_mgt $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg wk_hrs treat b_wk_hrs $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg goal treat b_goal $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg grit treat b_grit $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	


reg loc_int treat b_loc_int $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"

reg loc_po treat b_loc_po $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n7 = "`obs'"
	global r7 = "`r2'"
est sto est7
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef7="`b'`star'"
glo se7="(\hspace{-0.1cm}`se')"
	

reg loc_chance treat b_loc_chance $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n8 = "`obs'"
	global r8 = "`r2'"
est sto est8
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef8="`b'`star'"
glo se8="(\hspace{-0.1cm}`se')"
	
	
reg income_asp_w treat b_income_asp_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n9 = "`obs'"
	global r9 = "`r2'"
est sto est9
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef9="`b'`star'"
glo se9="(\hspace{-0.1cm}`se')"	

reg IND_skills treat b_IND_skills $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %12.2f M[1,1]
	local se	: disp %12.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n10 = "`obs'"
	global r10 = "`r2'"
est sto est10
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef10="`b'`star'"
glo se10="(\hspace{-0.1cm}`se')"	


// Control Means
summarize b_track if (sur_round==3 & tmt=="C")
	global CM1  : disp %9.3f r(mean)
summarize pric_mgt if (sur_round==3 & tmt=="C")
	global CM2  : disp %9.3f r(mean)
summarize wk_hrs if (sur_round==3 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize goal if (sur_round==3 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize grit if (sur_round==3 & tmt=="C")
	global CM5  : disp %9.3f r(mean)
summarize loc_int if (sur_round==3 & tmt=="C")
	global CM6  : disp %9.3f r(mean)
summarize loc_po if (sur_round==3 & tmt=="C")
	global CM7  : disp %9.3f r(mean)
summarize loc_chance if (sur_round==3 & tmt=="C")
	global CM8  : disp %9.3f r(mean)
summarize income_asp_w if (sur_round==3 & tmt=="C")
	global CM9  : disp %12.2f r(mean)
summarize IND_skills if (sur_round==3 & tmt=="C")
	global CM10  : disp %12.2f r(mean)


disp "ITT   &  $coef1    &  $coef2   &  $coef3   & $coef4    & $coef5	& $coef6	&  $coef7   & $coef8    & $coef9	& $coef10	"
disp "		& $se1		 & $se2		 & $se3		 & $se4		 & $se5		& $se6	&  $se7   & $se8    & $se9	& $se10	"
disp "		& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	& $qval6	&  $qval7   & $qval8    & $qval9	& $qval10	"

********************************************************************************
// Endline
	
	tex \multicolumn{11}{c}{\textit{Panel B: Endline (18--24 Months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	 & $coef4	 & $coef5	 & $coef6	 &  $coef7   & $coef8    & $coef9	& $coef10	 \\
	tex				& $se1		 & $se2		 & $se3		 & $se4		 & $se5		 & $se6	 	 &  $se7	 & $se8		 & $se9		& $se10		 \\
	tex				& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	 & $qval6	 &  $qval7   & $qval8    & $qval9 	& $qval10	 \\
	tex \addlinespace[5pt]	
	tex \midrule
		tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5		 & $n6	 & $n7		 & $n8		 & $n9	& $n10			 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5		 & $CM6	 & $CM7		 & $CM8		 & $CM9	& $CM10			 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5		 & $r6	 & $r7		 & $r8		 & $r9	& $r10			 \\

********************************************************************************	

	
* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{11}{@{} p{1.35\textwidth}}{\footnotesize{ \textit{Note:} Coefficients are ANCOVA estimates that control for the outcome at baseline, the respondent's location, marital status, household size, number of children, age, network size and level of education. ITT shows traditional intent to treat effects of participating in SBS. Tracking is an index about record keeping for the business with a maximum value of 3. Price management is an index about setting prices, running promotions, comparing prices with competitors, and negotiating for better prices with suppliers with a maximum value of 4. Goal setting is an index about setting goals for the business over various time horizons with a maximum value of 3. Work hours is the number of hours the respondent typically works in her main business. Our measures of grit follow \textcite{duckworth:grit:2007} and \textcite{duckworth:development:2009}. We draw our locus of control measures from \textcite{levenson:multidimensional:1973}. Internal, PO, and Chance is the dimension of the locus of control score. Positive values for Internal, PO and Chance provide evidence of improvements in locus of control measures independent of type. Index is an Anderson index of all outcomes using the swindex command in Stata. We winsorize the income aspirations variable at the 99th percentile. Values in columns marked with heading \textit{Levels} are values in UGX. We report White robust standard errors in parentheses. Romano-Wolf multiple hypothesis test q-values are presented in brackets. Q-values include the same controls as above and are computed within pre-specified families of outcomes.}}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................

/*******************************************************************************
	  TREATMENT EFFECTS ON BUSINESS OUTCOMES - EXTENSIVE MARGIN
	   
	Table 2. ITT Effects on Business Outcomes Extensive Margin
	File name: busout_itt.tex
*******************************************************************************/
lab var b0 "Own a Business"
lab var bus_count "No. Businesses" 
lab var sales_last3_bin "$>0$ Sales" 
lab var srp_bin "$>0$ Profits"
lab var ob_srp_bin "$>0$ Profits"
lab var tot_srp_bin "$>0$ Profits"
lab var IND_extmargin "Index of extensive margin outcomes"

******************************* Table File Code ********************************
* Start head ...................................................................
	cap texdoc close
	texdoc init "busout_itt.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize		
	tex \caption{ITT Effects on Business Outcomes: Extensive Margin \label{busout:itt}}
	tex \begin{tabular}{l*{7}{c}}			
	tex \toprule \toprule	
	tex &	\multicolumn{2}{c}{Business Creation}      &\multicolumn{2}{c}{Main Business}          &\multicolumn{1}{c}{\shortstack{Other\\Businesses}} &\multicolumn{1}{c}{All Businesses} &\multicolumn{1}{c}{}\\\cmidrule(lr){2-3}\cmidrule(lr){4-5}\cmidrule(lr){6-6}\cmidrule(lr){7-7}
	tex &	\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}&\multicolumn{1}{c}{(5)}&\multicolumn{1}{c}{(6)}&\multicolumn{1}{c}{(7)}\\
	tex &\multicolumn{1}{c}{Own a Business}&\multicolumn{1}{c}{No. Businesses}&\multicolumn{1}{c}{$>0$ Sales}&\multicolumn{1}{c}{$>0$ Profits}&\multicolumn{1}{c}{$>0$ Profits}&\multicolumn{1}{c}{$>0$ Profits}&\multicolumn{1}{c}{Index} \\ \midrule \\	
	
* End head .....................................................................

rwolf b0 bus_count sales_last3_bin srp_bin ob_srp_bin tot_srp_bin IND_extmargin if sur_round==2, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/7 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg b0 treat b_b0 $controls if sur_round==2, 
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"
	
	
reg bus_count treat b_bus_count $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg sales_last3_bin treat b_sales_last3_bin $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg srp_bin treat b_srp_bin $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg ob_srp_bin treat b_ob_srp_bin $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	


reg tot_srp_bin treat b_tot_srp_bin $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"	

reg IND_extmargin treat b_IND_extmargin $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n7 = "`obs'"
	global r7 = "`r2'"
est sto est7
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef7="`b'`star'"
glo se7="(\hspace{-0.1cm}`se')"	


// Control Means
summarize b0 if (sur_round==2 & tmt=="C")
	global CM1  : disp %9.3f r(mean)
summarize bus_count if (sur_round==2 & tmt=="C")
	global CM2  : disp %9.3f r(mean)
summarize sales_last3_bin if (sur_round==2 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize srp_bin if (sur_round==2 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize ob_srp_bin if (sur_round==2 & tmt=="C")
	global CM5  : disp %9.3f r(mean)
summarize tot_srp_bin if (sur_round==2 & tmt=="C")
	global CM6  : disp %9.3f r(mean)
summarize IND_extmargin if (sur_round==2 & tmt=="C")
	global CM7  : disp %9.3f r(mean)
	
	
disp "ITT   &  $coef1    &  $coef2   &  $coef3   & $coef4    & $coef5	& $coef6	& $coef7		"
disp "		& $se1		 & $se2		 & $se3		 & $se4		 & $se5		& $se6	& $se7			"
disp "		& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	& $qval6	& $qval7		"

********************************************************************************
// Midline
	
	tex \multicolumn{8}{c}{\textit{Panel A: Midline (6 months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	 & $coef4	 & $coef5	 & $coef6	& $coef7	 \\
	tex				& $se1		 & $se2		 & $se3		 & $se4		 & $se5		 & $se6	& $se7		 \\
	tex				& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	 & $qval6	& $qval7	 \\
	tex \addlinespace[5pt]	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5		 & $n6	& $n7		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5		 & $CM6	& $CM7		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5		 & $r6	& $r7		 \\
	tex \midrule \\

********************************************************************************	
rwolf b0 bus_count sales_last3_bin srp_bin ob_srp_bin tot_srp_bin IND_extmargin if sur_round==3, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/7 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}
	
reg b0 treat b_b0 $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"
	
	
reg bus_count treat b_bus_count $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg sales_last3_bin treat b_sales_last3_bin $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg srp_bin treat b_srp_bin $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg ob_srp_bin treat b_ob_srp_bin $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	


reg tot_srp_bin treat b_tot_srp_bin $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"

reg IND_extmargin treat b_IND_extmargin $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n7 = "`obs'"
	global r7 = "`r2'"
est sto est7
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef7="`b'`star'"
glo se7="(\hspace{-0.1cm}`se')"

// Control Means
summarize b0 if (sur_round==3 & tmt=="C")
	global CM1  : disp %9.3f r(mean)
summarize bus_count if (sur_round==3 & tmt=="C")
	global CM2  : disp %9.3f r(mean)
summarize sales_last3_bin if (sur_round==3 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize srp_bin if (sur_round==3 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize ob_srp_bin if (sur_round==3 & tmt=="C")
	global CM5  : disp %9.3f r(mean)
summarize tot_srp_bin if (sur_round==3 & tmt=="C")
	global CM6  : disp %9.3f r(mean)
summarize IND_extmargin if (sur_round==3 & tmt=="C")
	global CM7  : disp %9.3f r(mean)
	
	
disp "ITT   &  $coef1    &  $coef2   &  $coef3   & $coef4    & $coef5	& $coef6	& $coef7		"
disp "		& $se1		 & $se2		 & $se3		 & $se4		 & $se5		& $se6	& $se7			"
disp "		& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	& $qval6	& $qval7		"

// Endline
	
	tex \multicolumn{8}{c}{\textit{Panel B: Endline (18--24 months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	 & $coef4	 & $coef5	 & $coef6	& $coef7	 \\
	tex				& $se1		 & $se2		 & $se3		 & $se4		 & $se5		 & $se6	& $se7		 \\
	tex				& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	 & $qval6	& $qval7	 \\
	tex \addlinespace[5pt]	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5		 & $n6	& $n7		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5		 & $CM6	& $CM7		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5		 & $r6	& $r7		 \\
	
* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{8}{@{} p{1.1\textwidth}}{\footnotesize{\textit{Note:} We winsorize all sales and profit measures at the 99th percentile. Coefficients are ANCOVA estimates that control for the outcome at baseline, the respondent's location, marital status, household size, number of children, age, network size and level of education. ITT shows traditional intent to treat effects. We record revenues and profits for women without a business as zero to preserve balance from randomization. Column (3) presents a dummy variable equal to 1 if the sales for the 3 days prior the survey are greater than 0, columns (4)--(6) present a dummy variable equal to 1 if the self-reported profits for the last month are greater than 0, for either the main business, other businesses or all businesses. Index is an Anderson index of all outcomes using the swindex command in Stata. We report White robust standard errors in parentheses. Romano-Wolf multiple hypothesis test q-values are presented in brackets. Q-values include the same controls as above and are computed within pre-specified families of outcomes.}}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................

/*******************************************************************************
	  TREATMENT EFFECTS ON BUSINESS OUTCOMES - INTENSIVE MARGIN
								   	   
	Table 3. ITT Effects on Business Outcomes
	File name: busout_levels_itt.tex
*******************************************************************************/
lab var sales_last3_w "Levels"
lab var srp_w "Levels"
lab var ob_srp_w "Levels"
lab var tot_srp_w "Levels"
lab var IND_intmargin "Index of intensive margin outcomes"

******************************* Table File Code ********************************
* Start head ...................................................................
	cap texdoc close
	texdoc init "busout_levels_itt.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize		
	tex \caption{ITT Effects on Business Outcomes: Intensive Margin\label{busout:levels:itt}}
	tex \begin{tabular}{l*{5}{c}}			
	tex \toprule \toprule	
	tex &	\multicolumn{1}{c}{\shortstack{Main Business \\ Sales}}&\multicolumn{1}{c}{\shortstack{Main Business \\ Profits}}&\multicolumn{1}{c}{\shortstack{Other Businesses \\ Profits}}&\multicolumn{1}{c}{\shortstack{All Businesses \\ Profits}}&\multicolumn{1}{c}{}\\\cmidrule(lr){2-2}\cmidrule(lr){3-3}\cmidrule(lr){4-4}\cmidrule(lr){5-5}
	tex &	\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}&\multicolumn{1}{c}{(5)}\\
	tex &	\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Index}\\
	tex \midrule \\
	
* End head .....................................................................

rwolf sales_last3_w srp_w ob_srp_w tot_srp_w IND_intmargin if sur_round==2, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)
	
forval i=1/5 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg sales_last3_w treat b_sales_last3_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg srp_w treat b_srp_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg ob_srp_w treat b_ob_srp_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg tot_srp_w treat b_tot_srp_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"

reg IND_intmargin treat b_IND_intmargin $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"

// Control Means
summarize sales_last3_w if (sur_round==2 & tmt=="C")
	global CM1  : disp %9.2f r(mean)
summarize srp_w if (sur_round==2 & tmt=="C")
	global CM2  : disp %9.2f r(mean)
summarize ob_srp_w if (sur_round==2 & tmt=="C")
	global CM3  : disp %9.2f r(mean)
summarize tot_srp_w if (sur_round==2 & tmt=="C")
	global CM4  : disp %9.2f r(mean)
summarize IND_intmargin if (sur_round==2 & tmt=="C")
	global CM5  : disp %9.2f r(mean)

disp "ITT   &  $coef1    &  $coef2   &  $coef3   & $coef4 	& $coef5    "
disp "		& $se1		 & $se2		 & $se3		 & $se4	& $se5		 "
disp "		& $qval1	 & $qval2	 & $qval3	 & $qval4	& $qval5	 "

********************************************************************************
// Midline
	
	tex \multicolumn{6}{c}{\textit{Panel A: Midline (6 months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	 & $coef4	& $coef5	 \\
	tex				& $se1		 & $se2		 & $se3		 & $se4	& $se5		 \\
	tex				& $qval1	 & $qval2	 & $qval3	 & $qval4	& $qval5	 \\
	tex \addlinespace[5pt]	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4	& $n5		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4	& $CM5		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4	& $r5		 \\
	tex \midrule \\

********************************************************************************	
rwolf sales_last3_w srp_w ob_srp_w tot_srp_w IND_intmargin if sur_round==3, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)
	
forval i=1/5 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg sales_last3_w treat b_sales_last3_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg srp_w treat b_srp_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg ob_srp_w treat b_ob_srp_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg tot_srp_w treat b_tot_srp_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"

reg IND_intmargin treat b_IND_intmargin $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"

// Control Means
summarize sales_last3_w if (sur_round==3 & tmt=="C")
	global CM1  : disp %9.2f r(mean)
summarize srp_w if (sur_round==3 & tmt=="C")
	global CM2  : disp %9.2f r(mean)
summarize ob_srp_w if (sur_round==3 & tmt=="C")
	global CM3  : disp %9.2f r(mean)
summarize tot_srp_w if (sur_round==3 & tmt=="C")
	global CM4  : disp %9.2f r(mean)
summarize IND_intmargin if (sur_round==3 & tmt=="C")
	global CM5  : disp %9.2f r(mean)

disp "ITT   &  $coef1    &  $coef2   &  $coef3   & $coef4	& $coef5    "
disp "		& $se1		 & $se2		 & $se3		 & $se4	& $se5		 "
disp "		& $qval1	 & $qval2	 & $qval3	 & $qval4	& $qval5	 "

********************************************************************************
// Endline
	
	tex \multicolumn{6}{c}{\textit{Panel B: Endline (18--24 Months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	 & $coef4	& $coef5	 \\
	tex				& $se1		 & $se2		 & $se3		 & $se4	& $se5		 \\
	tex				& $qval1	 & $qval2	 & $qval3	 & $qval4	& $qval5	 \\
	tex \addlinespace[5pt]	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4	& $n5		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4	& $CM5		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4	& $r5		 \\

********************************************************************************

* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{6}{@{} p{0.90\textwidth}}{\footnotesize{ \textit{Note:} We winsorize all sales and profit measures at the 99th percentile. Coefficients are ANCOVA estimates that control for the outcome at baseline, the respondent's location, marital status, household size, number of children, age, network size and level of education. ITT shows traditional intent to treat effects. Column (1) presents the reported sales for the 3 days prior the survey, columns (2) to (4) present the self-reported profits for the last month for either the main business, other businesses, or all businesses. Values in columns marked with heading \textit{Levels} are values in UGX. We report White robust standard errors in parentheses. Index is an Anderson index of all outcomes using the swindex command in Stata. Romano-Wolf multiple hypothesis test q-values are presented in brackets. Q-values include the same controls as above and are computed within pre-specified families of outcomes.}}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................

/*******************************************************************************
	  TREATMENT EFFECTS ON EMPLOYMENT OUTCOMES
	   
	Table 4. ITT Effects on Employment Outcomes
	File name: emp_itt.tex
*******************************************************************************/
lab var emp "\shortstack{Any \\ Employment}"
lab var emp_outside "\shortstack{Wage \\ Employment}"
lab var wtp_w "\shortstack{Outside \\ Wage}"

******************************* Table File Code ********************************
* Start head ...................................................................
	cap texdoc close
	texdoc init "emp_itt.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize		
	tex \caption{ITT Effects on Employment Outcomes \label{emp:itt}}
	tex \begin{tabular}{l*{3}{c}}			
	tex \toprule \toprule	
	tex &	\multicolumn{2}{c}{Employment}	&	\multicolumn{1}{c}{}	\\\cmidrule(lr){2-3}
	tex &	\multicolumn{1}{c}{(1)}	&	\multicolumn{1}{c}{(2)}	&	\multicolumn{1}{c}{(3)}	\\
	tex &	\multicolumn{1}{c}{Any}		&	\multicolumn{1}{c}{Salaried}	&	\multicolumn{1}{c}{\shortstack{Outside \\ Wage}}	\\ \midrule \\

* End head .....................................................................

rwolf emp emp_outside wtp_w if sur_round==2, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/3 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg emp treat b_emp $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg emp_outside treat b_emp_outside $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg wtp_w treat b_wtp_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	


// Control Means
summarize emp if (sur_round==2 & tmt=="C")
	global CM1  : disp %9.2f r(mean)
summarize emp_outside if (sur_round==2 & tmt=="C")
	global CM2  : disp %9.2f r(mean)
summarize wtp_w if (sur_round==2 & tmt=="C")
	global CM3  : disp %9.3f r(mean)

disp "ITT   &  $coef1    &  $coef2   &  $coef3   	"
disp "		& $se1		 & $se2		 & $se3		 "
disp "		& $qval1	 & $qval2	 & $qval3	 "

********************************************************************************
// Midline
	
	tex \multicolumn{4}{c}{\textit{Panel A: Midline (6 months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	 \\
	tex				& $se1		 & $se2		 & $se3		 \\
	tex				& $qval1	 & $qval2	 & $qval3	 \\
	tex \addlinespace[5pt]	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 \\
	tex \midrule \\

********************************************************************************

rwolf emp emp_outside wtp_w if sur_round==3, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/3 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg emp treat b_emp $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg emp_outside treat b_emp_outside $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg wtp_w treat b_wtp_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	


// Control Means
summarize emp if (sur_round==3 & tmt=="C")
	global CM1  : disp %9.2f r(mean)
summarize emp_outside if (sur_round==3 & tmt=="C")
	global CM2  : disp %9.2f r(mean)
summarize wtp_w if (sur_round==3 & tmt=="C")
	global CM3  : disp %9.3f r(mean)


disp "ITT   &  $coef1    &  $coef2   &  $coef3   "
disp "		& $se1		 & $se2		 & $se3		 "
disp "		& $qval1	 & $qval2	 & $qval3	 "

********************************************************************************
// Endline
	
	tex \multicolumn{4}{c}{\textit{Panel B: Endline (18--24 Months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	 \\
	tex				& $se1		 & $se2		 & $se3		 \\
	tex				& $qval1	 & $qval2	 & $qval3	 \\
	tex \addlinespace[5pt]	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 \\

********************************************************************************

* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{4}{@{} p{0.48\textwidth}}{\footnotesize{ \textit{Note:} We winsorize Outside Wage at the 99th percentile. Coefficients are ANCOVA estimates that control for the outcome at baseline, the respondent's location, marital status, household size, number of children, age, network size and level of education. ITT shows traditional intent to treat effects. Any Employment is a binary variable equal to one if the woman reports being either employed by someone else or being self-employed. Salaried Employment is a binary varibale equal to one if the woman reports being employed by someone else. Outside Wage is the salary a woman requires to prefer working in an important private company instead of having her own shop. Index is an Anderson index of all outcomes using the swindex command in Stata. We report White robust standard errors in parentheses. Romano-Wolf multiple hypothesis test q-values are presented in brackets. Q-values include the same controls as above and are computed within families of outcomes.}}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................

est clear

/*******************************************************************************
 TREATMENT EFFECTS ON RE-INVESTMENTS AND SAVINGS OUTCOMES
	   
	Table 5. ITT Effects on Re-Investments Outcomes
	File name: reinvout_itt.tex
*******************************************************************************/
lab var savings_w "Levels"
lab var ba_val_w "Levels"
lab var ob_inv_w "Levels"
lab var IND_savings "Index on Savings and Re-Investments"

******************************* Table File Code ********************************
* Start head ...................................................................
	cap texdoc close
	texdoc init "reinvout_itt.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize		
	tex \caption{ITT Effects on Savings and Re-Investments Outcomes \label{reinvout:itt}}
	tex \begin{tabular}{l*{4}{c}}			
	tex \toprule \toprule	
	tex &\multicolumn{1}{c}{Savings}                &\multicolumn{1}{c}{Business Assests}       &\multicolumn{1}{c}{\shortstack{Investments in \\ Other Businesses}} \multicolumn{1}{c}{}\\\cmidrule(lr){2-2}\cmidrule(lr){3-3}\cmidrule(lr){4-4}
	tex &\multicolumn{1}{c}{(1)}&\multicolumn{1}{c}{(2)}&\multicolumn{1}{c}{(3)}&\multicolumn{1}{c}{(4)}\\
	tex &\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Levels}&\multicolumn{1}{c}{Index} \\ \midrule \\

* End head .....................................................................

rwolf savings_w ba_val_w ob_inv_w IND_savings if sur_round==2, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)
forval i=1/4 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg savings_w treat b_savings_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg ba_val_w treat b_ba_val_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(`se')"


reg ob_inv_w treat b_ob_inv_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"

reg IND_savings treat b_IND_savings $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"

// Control Means
summarize savings_w if (sur_round==2 & tmt=="C")
	global CM1  : disp %12.2f r(mean)
summarize ba_val_w if (sur_round==2 & tmt=="C")
	global CM2  : disp %12.2f r(mean)
summarize ob_inv_w if (sur_round==2 & tmt=="C")
	global CM3  : disp %12.2f r(mean)
summarize IND_savings if (sur_round==2 & tmt=="C")
	global CM4  : disp %12.2f r(mean)

disp "ITT   &  $coef1    &  $coef2   &  $coef3 	&  $coef4  "
disp "		& $se1		 & $se2		 & $se3	& $se4		 "
disp "		& $qval1	 & $qval2	 & $qval3	& $qval4	 "

********************************************************************************
// Midline
	
	tex \multicolumn{5}{c}{\textit{Panel A: Midline (6 months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	& $coef4 \\
	tex				& $se1		 & $se2		 & $se3	& $se4		 \\
	tex				& $qval1	 & $qval2	 & $qval3	& $qval4	 \\
	tex \addlinespace[5pt]	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3	& $n4		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3	& $CM4		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3	& $r4		 \\
	tex \midrule \\

********************************************************************************

rwolf savings_w ba_val_w ob_inv_w IND_savings if sur_round==3, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)
forval i=1/4 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg savings_w treat b_savings_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg ba_val_w treat b_ba_val_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(`se')"


reg ob_inv_w treat b_ob_inv_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"

reg IND_savings treat b_IND_savings $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
// Control Means
summarize savings_w if (sur_round==3 & tmt=="C")
	global CM1  : disp %12.2f r(mean)
summarize ba_val_w if (sur_round==3 & tmt=="C")
	global CM2  : disp %12.2f r(mean)
summarize ob_inv_w if (sur_round==3 & tmt=="C")
	global CM3  : disp %12.2f r(mean)
summarize IND_savings if (sur_round==3 & tmt=="C")
	global CM4  : disp %12.2f r(mean)

disp "ITT   &  $coef1    &  $coef2   &  $coef3	&  $coef4   "
disp "		& $se1		 & $se2		 & $se3	& $se4		 "
disp "		& $qval1	 & $qval2	 & $qval3	& $qval4	 "

********************************************************************************
// Endline
	
	tex \multicolumn{5}{c}{\textit{Panel B: Endline (18--24 Months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	& $coef4	 \\
	tex				& $se1		 & $se2		 & $se3	& $se4		 \\
	tex				& $qval1	 & $qval2	 & $qval3	& $qval4	 \\
	tex \addlinespace[5pt]	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3	& $n4		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3	& $CM4		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3	& $r4		 \\

********************************************************************************

* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{5}{@{} p{0.74\textwidth}}{\footnotesize{ \textit{Note:} We winsorize all savings and investment measures at the 99th percentile. Coefficients are ANCOVA estimates that control for the outcome at baseline, the respondent's location, marital status, household size, number of children, age, network size and level of education. ITT shows traditional intent to treat effects. Savings is the total amount held in all financial savings instruments. Business assets is the estimated monetary value of all assets held in the main business. Investments in other businesses is the total estimated monetary value of all investments in businesses other than the main business in the last 6 months. Values in columns marked with heading \textit{Levels} are values in UGX. Index is an Anderson index of all outcomes using the swindex command in Stata. We report White robust standard errors in parentheses. Romano-Wolf multiple hypothesis test q-values are presented in brackets. Q-values include the same controls as above and are computed within pre-specified families of outcomes.}}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................

/*******************************************************************************
	  TREATMENT EFFECTS ON HOUSEHOLD OUTCOMES
	   
	Table 6. ITT Effects on Household Outcomes
	File name: hhout_itt.tex
*******************************************************************************/
lab var dexp_hh_w "\shortstack{HH \\ Levels}"
lab var dexp_w "\shortstack{Participant \\ Levels}"
lab var mue_w "MUE"
lab var food_ins "\shortstack{Food \\ Insecurity}"
lab var remittances_w "Levels"
lab var IND_hh "Index of Household Outcomes"

******************************* Table File Code ********************************
* Start head ...................................................................
	cap texdoc close
	texdoc init "hhout_itt.tex", replace force
	tex \begin{table}[htbp]
	tex \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}
	tex \centering
	tex \footnotesize		
	tex \caption{ITT Effects on Household Outcomes \label{hhout:itt}}
	tex \begin{tabular}{l*{6}{c}}			
	tex \toprule \toprule	
	tex &	\multicolumn{2}{c}{Daily Expenditure}	&	\multicolumn{2}{c}{}	&	\multicolumn{1}{c}{Remittances} & \multicolumn{1}{c}{}	\\\cmidrule(lr){2-3}\cmidrule(lr){4-5}\cmidrule(lr){6-6}
	tex &	\multicolumn{1}{c}{(1)}	&	\multicolumn{1}{c}{(2)}	&	\multicolumn{1}{c}{(3)}	&	\multicolumn{1}{c}{(4)}	&	\multicolumn{1}{c}{(5)}	&	\multicolumn{1}{c}{(6)}	\\
	tex &	\multicolumn{1}{c}{\shortstack{HH \\ Levels}}		&	\multicolumn{1}{c}{\shortstack{Participant \\ Levels}}	&	\multicolumn{1}{c}{MUE}	&	\multicolumn{1}{c}{\shortstack{Food \\ Insecurity}}&	\multicolumn{1}{c}{Levels} 	&	\multicolumn{1}{c}{Index} \\ \midrule \\

* End head .....................................................................

rwolf dexp_hh_w  dexp_w mue_w food_ins  remittances_w IND_hh if sur_round==2, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/6 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg dexp_hh_w treat b_dexp_hh_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg dexp_w treat b_dexp_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg mue_w treat b_mue_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg food_ins treat b_food_ins $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg remittances_w treat b_remittances_w $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	

reg IND_hh treat b_IND_hh $controls if sur_round==2, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"	


// Control Means
summarize dexp_hh_w if (sur_round==2 & tmt=="C")
	global CM1  : disp %9.2f r(mean)
summarize dexp_w if (sur_round==2 & tmt=="C")
	global CM2  : disp %9.2f r(mean)
summarize mue_w if (sur_round==2 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize food_ins if (sur_round==2 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize remittances_w if (sur_round==2 & tmt=="C")
	global CM5  : disp %9.2f r(mean)
summarize IND_hh if (sur_round==2 & tmt=="C")
	global CM6  : disp %9.2f r(mean)

disp "ITT   &  $coef1    &  $coef2   &  $coef3   & $coef4    & $coef5	& $coef6	"
disp "		& $se1		 & $se2		 & $se3		 & $se4		 & $se5	& $se6		"
disp "		& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	& $qval6	"

********************************************************************************
// Midline
	
	tex \multicolumn{7}{c}{\textit{Panel A: Midline (6 months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	 & $coef4	 & $coef5	& $coef6	 \\
	tex				& $se1		 & $se2		 & $se3		 & $se4		 & $se5		& $se6	 \\
	tex				& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	& $qval6	 \\
	tex \addlinespace[5pt]	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5	& $n6		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5	& $CM6		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5	& $r6		 \\
	tex \midrule \\

********************************************************************************

rwolf dexp_hh_w dexp_w mue_w food_ins remittances_w  IND_hh if sur_round==3, indepvar(treat) controls(i.b_location b_mar b_div b_wid ib2.b_hh_size ib2.b_minors b_age b_network b_prim b_sec flag_b_age)  bl(_b) robust seed(123) holm
	matrix qvalues_treat = e(RW)

forval i=1/6 {
	local va`i':display %9.3f qvalues_treat[`i',3] 
	di "`va`i''"
	global qval`i' "[\hspace{-0.1cm}`va`i'']"
}

reg dexp_hh_w treat b_dexp_hh_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n1 = "`obs'"
	global r1 = "`r2'"
est sto est1
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef1="`b'`star'"
glo se1="(\hspace{-0.1cm}`se')"

reg dexp_w treat b_dexp_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n2 = "`obs'"
	global r2 = "`r2'"
est sto est2
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef2="`b'`star'"
glo se2="(\hspace{-0.1cm}`se')"


reg mue_w treat b_mue_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n3 = "`obs'"
	global r3 = "`r2'"
est sto est3
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef3="`b'`star'"
glo se3="(\hspace{-0.1cm}`se')"
	

reg food_ins treat b_food_ins $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.3f M[1,1]
	local se	: disp %9.3f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n4 = "`obs'"
	global r4 = "`r2'"
est sto est4
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef4="`b'`star'"
glo se4="(\hspace{-0.1cm}`se')"
	
	
reg remittances_w treat b_remittances_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n5 = "`obs'"
	global r5 = "`r2'"
est sto est5
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef5="`b'`star'"
glo se5="(\hspace{-0.1cm}`se')"	

reg IND_hh treat b_remittances_w $controls if sur_round==3, robust
	matrix M = r(table)
	matselrc M M, c(1) r(b se pvalue)
	local b		: disp %9.2f M[1,1]
	local se	: disp %9.2f M[2,1]
	local pval	: disp %4.3f M[3,1]
	
	local obs : disp %5.0f e(N)
	local r2 : disp %9.3f e(r2_a)
	
	global n6 = "`obs'"
	global r6 = "`r2'"
est sto est6
	
local star = ""
		if `pval' < 0.1 {
			local star = "\sym{*}"
			}
		if `pval' < 0.05 {
			local star = "\sym{**}"
		}
		if `pval' < 0.01 {
			local star = "\sym{***}"
			}
		
glo coef6="`b'`star'"
glo se6="(\hspace{-0.1cm}`se')"	

// Control Means
summarize dexp_hh_w if (sur_round==3 & tmt=="C")
	global CM1  : disp %9.2f r(mean)
summarize dexp_w if (sur_round==3 & tmt=="C")
	global CM2  : disp %9.2f r(mean)
summarize mue_w if (sur_round==3 & tmt=="C")
	global CM3  : disp %9.3f r(mean)
summarize food_ins if (sur_round==3 & tmt=="C")
	global CM4  : disp %9.3f r(mean)
summarize remittances_w if (sur_round==3 & tmt=="C")
	global CM5  : disp %9.2f r(mean)
summarize IND_hh if (sur_round==3 & tmt=="C")
	global CM6  : disp %9.2f r(mean)

disp "ITT   &  $coef1    &  $coef2   &  $coef3   & $coef4    & $coef5	& $coef6	"
disp "		& $se1		 & $se2		 & $se3		 & $se4		 & $se5	& $se6		"
disp "		& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	& $qval6	"

********************************************************************************
// Endline
	
	tex \multicolumn{7}{c}{\textit{Panel B: Endline (18--24 Months)}} \\\\[-1ex]
	tex ITT			& $coef1	 & $coef2	 & $coef3	 & $coef4	 & $coef5	& $coef6	 \\
	tex				& $se1		 & $se2		 & $se3		 & $se4		 & $se5	& $se6		 \\
	tex				& $qval1	 & $qval2	 & $qval3	 & $qval4	 & $qval5	& $qval6 \\
	tex \addlinespace[5pt]	
	tex \midrule
	tex Observations & $n1		 & $n2		 & $n3		 & $n4		 & $n5	& $n6		 \\
	tex Control Mean & $CM1		 & $CM2		 & $CM3		 & $CM4		 & $CM5	& $CM6		 \\
	tex Adj. R$^2$ 	 & $r1		 & $r2		 & $r3		 & $r4		 & $r5	& $r6		 \\

********************************************************************************

* Start foot ...................................................................
	tex \bottomrule \bottomrule
	tex \multicolumn{7}{@{} p{0.83\textwidth}}{\footnotesize{ \textit{Note:} We winsorize daily expenditures, MUE, and remittances at the 99th percentile. Coefficients are ANCOVA estimates that control for the outcome at baseline, the respondent's location, marital status, household size, number of children, age, network size and level of education. ITT shows traditional intent to treat effects. We calculate the MUE using consumption expenditures over the past week on seventeen food items, following the methods outlined in \textcite{Ligon:2020}. Higher values of the MUE indicate higher marginal utilities of expenditure, indicating that households are worse off. Food insecurity is a binary variable equal to one if the woman reports not having enough food more than once over the six months before the survey. Column (2) is included in column (1), however, we wanted to show the effect on the participating women expenditures as the information on the household corresponds to estimates the respondent thinks other members of the household have. Values in columns marked with heading \textit{Levels} are values in UGX. Index is an Anderson index of all outcomes using the swindex command in Stata. We report White robust standard errors in parentheses. Romano-Wolf multiple hypothesis test q-values are presented in brackets. Q-values include the same controls as above and are computed within pre-specified families of outcomes.}}
	tex \end{tabular}
	tex \end{table}
	texdoc close	
	
* End foot .....................................................................

est clear

/*******************************************************************************
	   CALCULATING SPILLOVER EFFECTS ON BUSINESS OUTCOMES BY NETWORK LINKS
	   
			Table 7. Spillover Effects on Business Outcomes at Endline
			File name: busout_network.tex
*******************************************************************************/
lab var IND_skills "Index"
lab var b0 "Ownership"
lab var srp_bin "$>0$"
lab var IND_extmargin "Index"
lab var IND_intmargin "Index"
lab var emp "Any"
lab var emp_outside "Salaried"

******************************* Any Network Link *******************************

	eststo: reg IND_skills networkB_wt b_network b_IND_skills if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M IND_skills_networkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize IND_skills if (sur_round==3 & tmt=="C" & networkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize IND_skills if (sur_round==3 & tmt=="C" & networkB_wt==0)
	estadd scalar CM  = r(mean)	
	

	eststo: reg b0 networkB_wt b_network b_b0 if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M b0_networkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize b0 if (sur_round==3 & tmt=="C" & networkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	
	summarize b0 if (sur_round==3 & tmt=="C" & networkB_wt==0)
	estadd scalar CM  = r(mean)


	eststo: reg srp_bin networkB_wt b_network b_srp_bin if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M srp_bin_networkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize srp_bin if (sur_round==3 & tmt=="C" & networkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize srp_bin if (sur_round==3 & tmt=="C" & networkB_wt==0)
	estadd scalar CM  = r(mean)	

	
	eststo: reg IND_extmargin networkB_wt b_network b_IND_extmargin if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M IND_extmargin_networkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize IND_extmargin if (sur_round==3 & tmt=="C" & networkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize IND_extmargin if (sur_round==3 & tmt=="C" & networkB_wt==0)
	estadd scalar CM  = r(mean)	
	
	
	eststo: reg IND_intmargin networkB_wt b_network b_IND_intmargin if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M IND_intmargin_networkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize IND_intmargin if (sur_round==3 & tmt=="C" & networkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize IND_intmargin if (sur_round==3 & tmt=="C" & networkB_wt==0)
	estadd scalar CM  = r(mean)	
	
	
	eststo: reg emp networkB_wt b_network b_emp if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M emp_networkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize emp if (sur_round==3 & tmt=="C" & networkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize emp if (sur_round==3 & tmt=="C" & networkB_wt==0)
	estadd scalar CM  = r(mean)	
	

	eststo: reg emp_outside networkB_wt b_network b_emp_outside if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M emp_outside_networkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize emp_outside if (sur_round==3 & tmt=="C" & networkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize emp_outside if (sur_round==3 & tmt=="C" & networkB_wt==0)
	estadd scalar CM  = r(mean)	
	
******************************* Friendship Link ********************************

	eststo: reg IND_skills friendnetworkB_wt b_network b_IND_skills if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M IND_skills_friendnetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize IND_skills if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize IND_skills if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
	estadd scalar CM  = r(mean)	
	

	eststo: reg b0 friendnetworkB_wt b_network b_b0 if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M b0_friendnetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize b0 if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	
	summarize b0 if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
	estadd scalar CM  = r(mean)


	eststo: reg srp_bin friendnetworkB_wt b_network b_srp_bin if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M srp_bin_friendnetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize srp_bin if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize srp_bin if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
	estadd scalar CM  = r(mean)	

	
	eststo: reg IND_extmargin friendnetworkB_wt b_network b_IND_extmargin if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M IND_extmargin_friendnetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize IND_extmargin if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize IND_extmargin if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
	estadd scalar CM  = r(mean)	
	
	
	eststo: reg IND_intmargin friendnetworkB_wt b_network b_IND_intmargin if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M IND_intmargin_friendnetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize IND_intmargin if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize IND_intmargin if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
	estadd scalar CM  = r(mean)	
	
	
	eststo: reg emp friendnetworkB_wt b_network b_emp if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M emp_friendnetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize emp if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize emp if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
	estadd scalar CM  = r(mean)	
	

	eststo: reg emp_outside friendnetworkB_wt b_network b_emp_outside if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M emp_outside_friendnetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize emp_outside if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize emp_outside if (sur_round==3 & tmt=="C" & friendnetworkB_wt==0)
	estadd scalar CM  = r(mean)		

******************************** Business Link *********************************

	eststo: reg IND_skills bpartnernetworkB_wt b_network b_IND_skills if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M IND_skills_bpartnernetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize IND_skills if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize IND_skills if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
	estadd scalar CM  = r(mean)	
	

	eststo: reg b0 bpartnernetworkB_wt b_network b_b0 if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M b0_bpartnernetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize b0 if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	
	summarize b0 if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
	estadd scalar CM  = r(mean)


	eststo: reg srp_bin bpartnernetworkB_wt b_network b_srp_bin if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M srp_bin_bpartnernetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize srp_bin if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize srp_bin if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
	estadd scalar CM  = r(mean)	

	
	eststo: reg IND_extmargin bpartnernetworkB_wt b_network b_IND_extmargin if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M IND_extmargin_bpartnernetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize IND_extmargin if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize IND_extmargin if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
	estadd scalar CM  = r(mean)	
	
	
	eststo: reg IND_intmargin bpartnernetworkB_wt b_network b_IND_intmargin if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M IND_intmargin_bpartnernetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize IND_intmargin if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize IND_intmargin if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
	estadd scalar CM  = r(mean)	
	
	
	eststo: reg emp bpartnernetworkB_wt b_network b_emp if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M emp_bpartnernetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize emp if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize emp if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
	estadd scalar CM  = r(mean)	
	

	eststo: reg emp_outside bpartnernetworkB_wt b_network b_emp_outside if sur_round==3 & treat==0, robust
	matrix M = r(table)
	matselrc M Coef_M, c(1) r(b se ll ul df)
	matrix Coef_M = Coef_M'
	matname Coef_M emp_outside_bpartnernetworkB, r(1) e	
	matrix sur_round=J(1,1,3)
	matname sur_round sur_round, c(1) e
	matrix mean_sd=J(1,2,.)
	matname mean_sd mean_control sd_control, c(1..2) e
	summarize emp_outside if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
		matrix mean_sd[1,1] = r(mean)
		matrix mean_sd[1,2] = r(sd)
	matrix Coef_M = Coef_M , sur_round , mean_sd
	
	summarize emp_outside if (sur_round==3 & tmt=="C" & bpartnernetworkB_wt==0)
	estadd scalar CM  = r(mean)		

******************************* Table File Code ********************************
esttab est1 est2 est3 est4 est5 est6 est7 using "busout_network_expanded.tex", replace ///
prehead("\begin{table}[htbp]\footnotesize \centering \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \caption{Spillover Effects on Business Outcomes at Endline \label{busout:spill}} \\ \begin{tabular}{l*{7}{c}} \toprule \toprule &\multicolumn{7}{c}{Control group only}     \\\cmidrule(lr){2-8}") ///
posthead("\midrule \\[-1ex] \multicolumn{8}{c}{\textit{Panel A: Any Network Link}} \\\\[-1ex]") ///
fragment ///
mgroups("Skills" "Business" "Profit" "Extensive Margin" "Intensive Margin" "Employment", pattern(1 1 1 1 1 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ////
keep(networkB_wt) coeflabel(networkB_wt "Link - Treated") ///
label scalars( "N Obs." "CM Control Mean" "r2_a Adj. R$^2$") sfmt(3) /// 

esttab est8 est9 est10 est11 est12 est13 est14 using "busout_network_expanded.tex", append ///
posthead("\midrule \\[-1ex] \multicolumn{8}{c}{\textit{Panel B: Friendship Link}} \\\\[-1ex]") ////
fragment ////
b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ////
keep(friendnetworkB_wt) coeflabel(friendnetworkB_wt "Link - Treated") ///
label scalars("CM Control Mean" "r2_a Adj. R$^2$"  "N Obs." ) sfmt(3) nomtitles nonumbers ///

esttab est15 est16 est17 est18 est19 est20 est21 using "busout_network_expanded.tex", append ///
posthead("\midrule \\[-1ex] 	\multicolumn{8}{c}{\textit{Panel C: Business Link}} \\\\[-1ex]") ////
fragment ////
b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ////
keep(bpartnernetworkB_wt) coeflabel(bpartnernetworkB_wt "Link - Treated") ///
label scalars("CM Control Mean" "r2_a Adj. R$^2$"  "N Obs." ) sfmt(3) nomtitles nonumbers ///
prefoot("\bottomrule") ///
postfoot("\bottomrule \bottomrule  \multicolumn{8}{@{} p{1.05\textwidth}}{\footnotesize{ \textit{Note:} Coefficients are ANCOVA estimates that control for the outcome at baseline, and baseline network size. All Indeces are Anderson indeces of the respective outcome groups using the swindex command in Stata. Columns 2-3 are binary indicators. Any Employment is a binary variable equal to one if the woman reports being either employed by someone else or being self-employed. Salaried Employment is a binary varibale equal to one if the woman reports being employed by someone else. We report White robust standard errors in parentheses. These results correspond to spillover effects for the control group at endline. }} \end{tabular} \\ \end{table}")

est clear